********************************************************************************
********************************************************************************
****
**** Replication Code File 3 for:
****   Gerber, Huber, Biggers, and Hendry. "Self Interest, Beliefs, and Policy
****   Opinions: Understanding the Economic Source of Immigration Policy
****   Preferences." Political Research Quarterly.
****
****     - This file reads in the recoded restricted raw dataset:
****
****         SelfInterestBeliefsPolicyOpinionsPRQ-Recodes.dta
****
****       and performs all of the analyses in the main text and the online
****       supplemental appendix
****
********************************************************************************
********************************************************************************

clear
set more off

log using Logs/03_Analysis-Run.txt, text replace

use Data/SelfInterestBeliefsPolicyOpinionsPRQ-Recodes.dta, clear

********************************************************************************
** Table C1: Relationship Between Respondent Skill Level and Relative Opposition
**   to Low-skilled versus Highly Skilled Immigrants
********************************************************************************

*run model quietly to limit all models to cases without missing data
quietly regress oppose_hs oppose_ls educ_hh female age black white latino /*
  */hs_dummy ideo5 pid7
gen useme = 1 if e(sample)

*education as worker skill level
regress net_oppose_ls educ_hh female age black white latino ideo5 pid7 /*
  */[aweight = weight] if useme == 1, robust
outreg2 using Tables/TableC01_ReplicationAndMotivation, /*
  */lab alpha(0.001, 0.01, 0.05) dec(3) bracket aster(se) excel replace /*
  */title("Table C1: Relationship Between Respondent Skill Level and Relative Opposition to Low-skilled versus Highly Skilled Immigrants") /*
  */addnote("Note: Dependent variable is scored as opposition to low-skilled immigration (0-1) minus opposition to highly skilled immigration (0-1), and therefore ranges from -1 to 1. Cell entries are OLS coefficient estimates with robust (Huber/White) standard errors in brackets.")

*self assessment as worker skill level
regress net_oppose_ls hs_dummy female age black white latino ideo5 pid7 /*
  */[aweight = weight] if useme == 1, robust
outreg2 using Tables/TableC01_ReplicationAndMotivation, /*
  */lab alpha(0.001, 0.01, 0.05) dec(3) bracket aster(se) excel append

*self assessment and education measures
regress net_oppose_ls hs_dummy educ_hh female age black white latino ideo5 /*
  */pid7 [aweight = weight] if useme == 1, robust
outreg2 using Tables/TableC01_ReplicationAndMotivation, /*
  */lab alpha(0.001, 0.01, 0.05) dec(3) bracket aster(se) excel append

*test reported in text describing Table C1
test hs_dummy educ_hh

*summary statistics for sample in Table C1
outsum net_oppose_ls hs_dummy educ_hh female age black white latino ideo5 /*
  */pid7 [aweight = weight] if useme == 1 using /*
  */Tables/TableE03_SummaryStatsWeightedAppendix, /*
  */title("Table E3: Summary Statistics, Weighted, Appendix Analyses") /*
  */ctitle("Table C1 Sample") bracket replace
outsum net_oppose_ls hs_dummy educ_hh female age black white latino ideo5 /*
  */pid7 if useme == 1 using Tables/TableE04_SummaryStatsUnweightedAppendix, /*
  */title("Table E4: Summary Statistics, Unweighted, Appendix Analyses") /*
  */ctitle("Table C1 Sample") bracket replace

*correlation reported in footnote 1 of supplemental appendix
pwcorr hs_dummy educ_hh [aweight = weight] if useme == 1, sig
drop useme

********************************************************************************
** endnote 13: t-tests for item nonresponse rates across experimental conditions
********************************************************************************

gen treat1 = YL45_49_69_treat if YL45_49_69_treat == 1 | YL45_49_69_treat == 2
gen treat2 = YL45_49_69_treat if YL45_49_69_treat == 1 | YL45_49_69_treat == 3
gen treat3 = YL45_49_69_treat if YL45_49_69_treat == 2 | YL45_49_69_treat == 3
foreach var of varlist rc_YL45_50 rc_YL45_51 rc_YL45_52 rc_YL45_49 rc_YL45_53 {
  gen `var'_miss = `var' == .
  ttest `var'_miss, by(treat1)
  ttest `var'_miss, by(treat2)
  ttest `var'_miss, by(treat3)
  drop `var'_miss
}
drop treat1 treat2 treat3

********************************************************************************
** construct baseline samples used in all remaining analyses
********************************************************************************

*restrict to cases of high or low-skilled immigrants treatments
keep if YL45_49_69_treat == 1 | YL45_49_69_treat == 2

*drop cases with at least half of these 5 variables missing
egen nummissing = rowmiss(YL45_50 YL45_51 YL45_52 YL45_49 YL45_53)
drop if nummissing == 3 | nummissing == 4 | nummissing == 5
drop nummissing

*replace missing values with midpoint
foreach var of varlist rc_YL45_49 rc_YL45_50 rc_YL45_51 rc_YL45_52 rc_YL45_53 {
  replace `var' = .5 if `var' == .
}

********************************************************************************
** Figure 1: Average Evaluations of Personal Economic Effects of Additional
**   Immigration by Immigrant Type
********************************************************************************

preserve
  *Replace labor-market effects question with missing if the respondent is not
  *  working, looking for work, or in a household with someone doing the same
  replace rc_YL45_50 = . if (YL45_10 != 1 & YL45_12 != 2 & YL45_17 != 1 & /*
    */YL45_18 != 2)

  *Store variable labels for post-collapse
  foreach v of var * {
    local l`v' : variable label `v'
    if `"`l`v''"' == "" {
      local l`v' "`v'"
    }
  }
  
  *Store p-values for difference-of-means tests in comparison of highly and low-
  *  skilled cases in last record, where the treatment variable is set to
  *  missing. Note that we use regression here to allow for weighting.
  count
  local newobs = r(N) + 1
  set obs `newobs'

  qui foreach var of varlist rc_YL45_50 rc_YL45_51 rc_YL45_52 rc_YL45_49 /*
    */rc_YL45_53 `larger_conseq' `other_conseq' `wherefrom' {
    regress `var' YL45_49_69_treat if YL45_49_69_treat == 1 | /*
	  */YL45_49_69_treat == 2 [aweight = weight]
    replace `var' = (2 * ttail(e(df_r), abs(_b[YL45_49_69_treat] / /*
	  */_se[YL45_49_69_treat]))) if YL45_49_69_treat == .
    replace weight = 1  if YL45_49_69_treat == .
  }

  *Store 95% confidence intervals  for means
  qui foreach var of varlist rc_YL45_50 rc_YL45_51 rc_YL45_52 rc_YL45_49 /*
    */rc_YL45_53 `larger_conseq' `other_conseq' `wherefrom' {
    ci means `var' if YL45_49_69_treat == 1  [aweight = weight]
    gen hici_`var' = r(ub) if YL45_49_69_treat == 1
    gen loci_`var' = r(lb) if YL45_49_69_treat == 1
    ci means `var' if YL45_49_69_treat == 2  [aweight = weight]
    replace hici_`var' = r(ub) if YL45_49_69_treat == 2
    replace loci_`var' = r(lb) if YL45_49_69_treat == 2
  }

  collapse (mean) rc_YL45_50 rc_YL45_51 rc_YL45_52 rc_YL45_49 rc_YL45_53 /*
    */`larger_conseq' `other_conseq' `wherefrom' hici_* loci_* /*
	*/[aweight = weight], by(YL45_49_69_treat)

  foreach v of var rc_YL45_50 rc_YL45_51 rc_YL45_52 rc_YL45_49 rc_YL45_53 /*
    */`larger_conseq' `other_conseq' `wherefrom' {
    label var `v' "`l`v''"
  }

  set obs 100
  gen temp = _n 

  local varctr = 0
  gen outcome = .
  gen outcome_hici = .
  gen outcome_lowci = .
  gen outcomectr = .
  gen outcomeskill = .
  gen outcomeplocation = .
  gen outcomepvaluelabel = ""

  local graphhorizlabel = ""

  foreach var of varlist rc_YL45_50 rc_YL45_51 rc_YL45_52 rc_YL45_49 /*
    */rc_YL45_53 {
    if `varctr' != 0 {
      replace outcome = 0 in `varctr' 
      replace outcomectr = `varctr' in `varctr'
    }
	
    local varctr = `varctr' + 1

    *capture variable label and parse it into two parts based on word count
    local temp : variable label `var'
    local numwords = wordcount("`temp'")
    local firstlabel = ""
    local secondlabel = ""
    forvalues labelctr = 1(1)`numwords' {
      if `labelctr' <= int(`numwords' / 2) {
        local firstlabel = "`firstlabel'" + " " + word("`temp'", `labelctr')
      }
      else {
        local secondlabel = "`secondlabel'" + " " + word("`temp'", `labelctr')
      }
    }
    local firstlabel = trim("`firstlabel'")
    local secondlabel = trim("`secondlabel'")

    *p-value is stored in the location where treatment indicator is missing
    qui summ `var' if YL45_49_69_treat == .
    replace outcomepvaluelabel = "  " + /*
	  */trim("p=" + string(`r(mean)', "%9.3f")) in `varctr'
    replace outcomeplocation = 1 in `varctr'
    replace outcomeplocation = .9 in `varctr' if /*
	  */int(`varctr' / 2) == (`varctr' / 2)

    sum `var' if YL45_49_69_treat == 1
    replace outcome = r(mean) in `varctr'
    summ hici_`var' if YL45_49_69_treat == 1
    replace outcome_hici = r(mean) in `varctr'
    summ loci_`var' if YL45_49_69_treat == 1
    replace outcome_lowci = r(mean) in `varctr'
    replace outcomectr = `varctr' in `varctr'
    replace outcomeskill = 1 in `varctr'
    local graphhorizlabel `"`graphhorizlabel' `varctr' "`firstlabel'""'
    local varctr = `varctr' + 1

    sum `var' if YL45_49_69_treat == 2
    replace outcome = r(mean) in `varctr' 
    summ hici_`var' if YL45_49_69_treat == 2
    replace outcome_hici = r(mean) in `varctr'
    summ loci_`var' if YL45_49_69_treat == 2
    replace outcome_lowci = r(mean) in `varctr'
    replace outcomectr = `varctr' in `varctr'
    replace outcomeskill = 2 in `varctr'
    local graphhorizlabel `"`graphhorizlabel' `varctr' "`secondlabel'""' 
	local varctr = `varctr' + 1
  }

  gen temp2 = .05 if  outcomeskill == 1 | outcomeskill == 2
  gen numastext = string(outcome, "%9.3f")

  twoway (bar outcome outcomectr if outcomeskill == 1) /*
    */(bar outcome outcomectr if outcomeskill == 2) /*
    */(rcap outcome_hici outcome_lowci outcomectr, lcolor(black) /*
	*/  msize(medium)) /*
    */(scatter outcomeplocation outcomectr, mlabel(outcomepvaluelabel) /*
	*/  msymbol(none) mlabsize(vsmall) mlabcolor(black) mlabposition(0)) /*
    */(scatter temp2 outcomectr, mlabel(numastext) msymbol(none) /*
	*/  mlabsize(vsmall) mlabcolor(black) mlabposition(0)), /*
    */ytitle("Agreement (1 = Strongly Agree, 0 = Strongly Disagree)" " ", /*
	*/  size(vsmall)) /*
    */yscale(range(0 1)) ylabel(0(.25)1, labsize(vsmall)) xtitle("") /*       
	*/yline(.5) /*
    */xlabel(1.3 "Increase household" 1.7 "chance of job or wage loss" 4.3 /*
	*/  "Increase" 4.7 "household taxes" 7.3 "Reduce household access" 7.7 /*
	*/  "to government benefits" 10.3 "Increase household costs" 10.7 /*
	*/  "of goods and services" 13.3 "Overall hurt" 13.7 /*
	*/  "household finances", noticks labsize(vsmall) labcolor(black) /*
	*/  angle(forty_five) labgap(small)) /*
	*/legend(order(1 "Highly Skilled" 2 "Low-Skilled")) scheme(s1mono) /*
    */name(all_own_econeffects, replace) xsize(11) ysize(8)
  graph export /*
    */Figures/Figure01_PersonalEconEffectsByImmigrantType.pdf, as(pdf) replace

restore

graph drop _all

********************************************************************************
** endnote 11: individual vs. sociotropic (sociotropic defined at both
**   community and national levels)
********************************************************************************

**costs of goods and services, highly skilled immigrants
*personal and community sociotropic
corr YL45_49 YL45_64 if YL45_64_69_treat == 1 & YL45_49_69_treat == 1
*personal and national sociotropic
corr YL45_49 YL45_64 if YL45_64_69_treat == 2 & YL45_49_69_treat == 1

**costs of goods and services, low-skilled immigrants
*personal and community sociotropic
corr YL45_49 YL45_64 if YL45_64_69_treat == 1 & YL45_49_69_treat == 2
*personal and national sociotropic
corr YL45_49 YL45_64 if YL45_64_69_treat == 2 & YL45_49_69_treat == 2

**access to gov't services and benefits, highly skilled immigrants
*personal and community sociotropic
corr YL45_52 YL45_67 if YL45_64_69_treat == 1 & YL45_49_69_treat == 1
*personal and national sociotropic
corr YL45_52 YL45_67 if YL45_64_69_treat == 2 & YL45_49_69_treat == 1

**access to gov't services and benefits, low-skilled immigrants
*personal and community sociotropic
corr YL45_52 YL45_67 if YL45_64_69_treat == 1 & YL45_49_69_treat == 2
*personal and national sociotropic
corr YL45_52 YL45_67 if YL45_64_69_treat == 2 & YL45_49_69_treat == 2

**lose job or wage go down, highly skilled immigrants
*personal and community sociotropic
corr YL45_50 YL45_65 if YL45_64_69_treat == 1 & YL45_49_69_treat == 1
*personal and national sociotropic
corr YL45_50 YL45_65 if YL45_64_69_treat == 2 & YL45_49_69_treat == 1

**lose job or wage go down, low-skilled immigrants
*personal and community sociotropic
corr YL45_50 YL45_65 if YL45_64_69_treat == 1 & YL45_49_69_treat == 2
*personal and national sociotropic
corr YL45_50 YL45_65 if YL45_64_69_treat == 2 & YL45_49_69_treat == 2

**taxes, highly skilled immigrants
*personal and community sociotropic
corr YL45_51 YL45_66 if YL45_64_69_treat == 1 & YL45_49_69_treat == 1
*personal and national sociotropic
corr YL45_51 YL45_66 if YL45_64_69_treat == 2 & YL45_49_69_treat == 1

**taxes, low-skilled immigrants
*personal and community sociotropic
corr YL45_51 YL45_66 if YL45_64_69_treat == 1 & YL45_49_69_treat == 2
*personal and national sociotropic
corr YL45_51 YL45_66 if YL45_64_69_treat == 2 & YL45_49_69_treat == 2

********************************************************************************
** Table D1: Question Wording and Survey Marginals for Measures of Personal
**   Economic Effects of Immigration
********************************************************************************

preserve
  *labor-market threat item, restricted to those working/looking or in HH with
  *  someone doing the same
  gen  rc_YL45_99 = rc_YL45_50 
  replace rc_YL45_99 = . if (YL45_10 != 1 & YL45_12 != 2 & YL45_17 != 1 & /*
    */YL45_18 != 2)
  keep YL45_49_69_treat rc_YL45_50 rc_YL45_99 rc_YL45_51 rc_YL45_52 /*
    */rc_YL45_49 rc_YL45_53 weight
  order YL45_49_69_treat rc_YL45_50 rc_YL45_99 rc_YL45_51 rc_YL45_52 /*
    */rc_YL45_49 rc_YL45_53
  gen id = _n
  reshape long rc_YL45_, i(id) j(qnum)
  gen is0 = rc_YL45_ == 0
  gen is25 = rc_YL45_ == .25
  gen is50 = rc_YL45_ == .50
  gen is75 = rc_YL45_ == .75
  gen is100 = rc_YL45_ == 1
  drop if rc_YL45_ == .
  gen obs = 1
  collapse (mean) is0 - is100 (sum) obs [aweight = weight], /*
    */by(qnum YL45_49_69_treat)
  replace qnum = 1 if qnum == 50
  replace qnum = 2 if qnum == 99 
  replace qnum = 3 if qnum == 51
  replace qnum = 4 if qnum == 52
  replace qnum = 5 if qnum == 49
  replace qnum = 6 if qnum == 53
  sort qnum YL45_49_69_treat 
  cl

  putexcel set Tables/TableD01_SurveyMarginals-EconomicConsequences, replace
    putexcel A1 = ("Table D1: Question Wording and Survey Marginals for Measures of Personal Economic Effects of Immigration")
    putexcel A2 = ("Question") B2 = ("Immigrant Type") C2 = ("Response Options")
    putexcel C3 = ("Strongly disagree") D3 = ("Somewhat disagree") /*
	  */E3 = ("Neither agree nor disagree") F3 = ("Somewhat agree") /*
	  */G3 = ("Strongly agree")
    putexcel A4 = ("Do you agree or disagree with the following statement: Increasing the number of [highly skilled/low-skilled] immigrants allowed to enter the U.S. will increase the chances that you or someone else in your household will lose their job or have their wages go down?")
   	putexcel C6 = ("Strongly disagree") E6 = ("Somewhat disagree") /*
	  */F6 = ("Neither agree nor disagree") G6 = ("Somewhat agree") /*
	  */H6 = ("Strongly agree")
    putexcel A7 = ("Households in Labor Market only: Do you agree or disagree with the following statement: Increasing the number of [highly skilled/low-skilled] immigrants allowed to enter the U.S. will increase the chances that you or someone else in your household will lose their job or have their wages go down?")
   	putexcel D9 = ("Decrease my taxes a lot") /*
	  */E9 = ("Decrease my taxes a little") /*
	  */F9 = ("Have no effect on my taxes") /*
	  */G9 = ("Increase my taxes a little") H9 = ("Increase my taxes a lot")
    putexcel A10 = ("Some people say that admitting more [highly skilled/low-skilled] immigrants to the United States will increase taxes because immigrants will place greater demands on government services, while others say that it will decrease taxes because these immigrants will pay more in taxes than they use in services.  What about you?  Admitting more [highly skilled/low-skilled] immigrants will...")
    putexcel D12 = ("Increase them greatly") /*
	  */E12 = ("Increase them somewhat") F12 = ("Have no effect") /*
	  */G12 = ("Reduce them somewhat") H12 = ("Reduce them greatly")
    putexcel A13 = ("Some people say that admitting more [highly skilled/low-skilled] immigrants to the United States will mean that more people take advantage of government services or receive government benefits, reducing what’s available to current citizens. What about you? How do you think that increasing the number of [highly skilled/low-skilled] immigrants will affect the government services available to you and your household?")
    putexcel D15 = ("Decrease my household's costs a lot") /*
	  */E15 = ("Decrease my household's costs a little") /*
	  */F15 = ("Have no effect on my household's costs") /*
	  */G15 = ("Increase my household's costs a little") /*
	  */H15 = ("Increase my household's costs a lot")
    putexcel A16 = ("One argument for admitting more [highly skilled/low-skilled] immigrants to the United States is that their work will reduce the costs of goods and services that other Americans use.  How do you think that increasing the number of [highly skilled/low-skilled] immigrants allowed to enter the U.S. will affect your household’s costs? It will...")
    putexcel D18 = ("The overall effect would be very positive for me") /*
	  */E18 = ("The overall effect would be somewhat positive for me") /*
	  */F18 = ("There would be no effect for me") /*
	  */G18 = ("The overall effect would be somewhat negative for me") /*
	  */H18 = ("The overall effect would be very negative for me")
    putexcel A19 = ("When you think about all of the potential positive and negative economic effects of increasing the number of  [highly skilled/low-skilled] immigrants coming to the United States, do you think the overall effect would be positive or negative for you and your household’s finances?")
    foreach i in 4 7 10 13 16 19 {
      local next = `i' + 1
      putexcel B`i' = ("Highly skilled")
      putexcel B`next' = ("Low-skilled")
    }
    forvalues i = 1/12 {
      if `i' == 1 | `i' == 2 {
        local counter = `i' + 3
      }
      if `i' == 3 | `i' == 4 {
        local counter = `i' + 4
      }
      if `i' == 5 | `i' == 6 {
        local counter = `i' + 5
      }
      if `i' == 7 | `i' == 8 {
        local counter = `i' + 6
      }
      if `i' == 9 | `i' == 10 {
        local counter = `i' + 7
      }
      if `i' == 11 | `i' == 12 {
        local counter = `i' + 8
      }
      qui sum is0 if _n == `i'
      local cell1 = round(100 * `r(mean)', .01)
      qui sum is25 if _n == `i'
      local cell2 = round(100 * `r(mean)', .01)
      qui sum is50 if _n == `i'
      local cell3 = round(100 * `r(mean)', .01)
      qui sum is75 if _n == `i'
      local cell4 = round(100 * `r(mean)', .01)
      qui sum is100 if _n == `i'
      local cell5 = round(100 * `r(mean)', .01)
      putexcel C`counter' = ("`cell1'%") D`counter' = ("`cell2'%") /*
	    */E`counter' = ("`cell3'%") F`counter' = ("`cell4'%") /*
		*/G`counter' = ("`cell5'%")
    }
    qui sum obs if _n == 1
    local unweightednhs = round(`r(mean)', 1)
    qui sum obs if _n == 2
    local unweightednls = round(`r(mean)', 1)
    qui sum obs if _n == 3
    local unweightednhslm = round(`r(mean)', 1)
    qui sum obs if _n == 4
    local unweightednlslm = round(`r(mean)', 1)
    putexcel A21 = ("Weighted percentages in each cell. Unweighted N=`unweightednhs' in highly skilled condition and `unweightednls' in the low-skilled condition. In the labor market subsample, unweighted N=`unweightednhslm' and `unweightednlslm', respectively.")
restore

********************************************************************************
** Table D2: Question Wording and Survey Marginals for Measures of Personal
**   Economic Effects of Immigration, Highly Skilled Respondents
********************************************************************************

preserve
  keep if hs_dummy == 1
  *labor-market threat item, restricted to those working/looking or in HH with
  *  someone doing the same
  gen rc_YL45_99 = rc_YL45_50 
  replace rc_YL45_99 = . if (YL45_10 != 1 & YL45_12 != 2 & YL45_17 != 1 & /*
    */YL45_18 != 2)
  keep YL45_49_69_treat rc_YL45_50 rc_YL45_99 rc_YL45_51 rc_YL45_52 /*
    */rc_YL45_49 rc_YL45_53 weight
  order YL45_49_69_treat rc_YL45_50 rc_YL45_99 rc_YL45_51 rc_YL45_52 /*
    */rc_YL45_49 rc_YL45_53
  gen id = _n
  reshape long rc_YL45_, i(id) j(qnum)
  gen is0 = rc_YL45_ == 0
  gen is25 = rc_YL45_ == .25
  gen is50 = rc_YL45_ == .50
  gen is75 = rc_YL45_ == .75
  gen is100 = rc_YL45_ == 1
  drop if rc_YL45_ == .
  gen obs = 1
  collapse (mean) is0 - is100 (sum) obs [aweight = weight], /*
    */by(qnum YL45_49_69_treat)
  replace qnum = 1 if qnum == 50
  replace qnum = 2 if qnum == 99 
  replace qnum = 3 if qnum == 51
  replace qnum = 4 if qnum == 52
  replace qnum = 5 if qnum == 49
  replace qnum = 6 if qnum == 53
  sort qnum YL45_49_69_treat 
  cl

  putexcel set Tables/TableD02_SurveyMarginals-EconomicConsequences-HS, replace
    putexcel A1 = ("Table D2: Question Wording and Survey Marginals for Measures of Personal Economic Effects of Immigration, Highly Skilled Respondents")
    putexcel A2 = ("Question") B2 = ("Immigrant Type") C2 = ("Response Options")
    putexcel C3 = ("Strongly disagree") D3 = ("Somewhat disagree") /*
	  */E3 = ("Neither agree nor disagree") F3 = ("Somewhat agree") /*
	  */G3 = ("Strongly agree")
    putexcel A4 = ("Do you agree or disagree with the following statement: Increasing the number of [highly skilled/low-skilled] immigrants allowed to enter the U.S. will increase the chances that you or someone else in your household will lose their job or have their wages go down?")
   	putexcel C6 = ("Strongly disagree") E6 = ("Somewhat disagree") /*
	  */F6 = ("Neither agree nor disagree") G6 = ("Somewhat agree") /*
	  */H6 = ("Strongly agree")
    putexcel A7 = ("Households in Labor Market only: Do you agree or disagree with the following statement: Increasing the number of [highly skilled/low-skilled] immigrants allowed to enter the U.S. will increase the chances that you or someone else in your household will lose their job or have their wages go down?")
   	putexcel D9 = ("Decrease my taxes a lot") /*
	  */E9 = ("Decrease my taxes a little") /*
	  */F9 = ("Have no effect on my taxes") /*
	  */G9 = ("Increase my taxes a little") H9 = ("Increase my taxes a lot")
    putexcel A10 = ("Some people say that admitting more [highly skilled/low-skilled] immigrants to the United States will increase taxes because immigrants will place greater demands on government services, while others say that it will decrease taxes because these immigrants will pay more in taxes than they use in services.  What about you?  Admitting more [highly skilled/low-skilled] immigrants will...")
    putexcel D12 = ("Increase them greatly") /*
	  */E12 = ("Increase them somewhat") F12 = ("Have no effect") /*
	  */G12 = ("Reduce them somewhat") H12 = ("Reduce them greatly")
    putexcel A13 = ("Some people say that admitting more [highly skilled/low-skilled] immigrants to the United States will mean that more people take advantage of government services or receive government benefits, reducing what’s available to current citizens. What about you? How do you think that increasing the number of [highly skilled/low-skilled] immigrants will affect the government services available to you and your household?")
    putexcel D15 = ("Decrease my household's costs a lot") /*
	  */E15 = ("Decrease my household's costs a little") /*
	  */F15 = ("Have no effect on my household's costs") /*
	  */G15 = ("Increase my household's costs a little") /*
	  */H15 = ("Increase my household's costs a lot")
    putexcel A16 = ("One argument for admitting more [highly skilled/low-skilled] immigrants to the United States is that their work will reduce the costs of goods and services that other Americans use.  How do you think that increasing the number of [highly skilled/low-skilled] immigrants allowed to enter the U.S. will affect your household’s costs? It will...")
    putexcel D18 = ("The overall effect would be very positive for me") /*
	  */E18 = ("The overall effect would be somewhat positive for me") /*
	  */F18 = ("There would be no effect for me") /*
	  */G18 = ("The overall effect would be somewhat negative for me") /*
	  */H18 = ("The overall effect would be very negative for me")
    putexcel A19 = ("When you think about all of the potential positive and negative economic effects of increasing the number of  [highly skilled/low-skilled] immigrants coming to the United States, do you think the overall effect would be positive or negative for you and your household’s finances?")
    foreach i in 4 7 10 13 16 19 {
      local next = `i' + 1
      putexcel B`i' = ("Highly skilled")
      putexcel B`next' = ("Low-skilled")
    }
    forvalues i = 1/12 {
      if `i' == 1 | `i' == 2 {
        local counter = `i' + 3
      }
      if `i' == 3 | `i' == 4 {
        local counter = `i' + 4
      }
      if `i' == 5 | `i' == 6 {
        local counter = `i' + 5
      }
      if `i' == 7 | `i' == 8 {
        local counter = `i' + 6
      }
      if `i' == 9 | `i' == 10 {
        local counter = `i' + 7
      }
      if `i' == 11 | `i' == 12 {
        local counter = `i' + 8
      }
      qui sum is0 if _n == `i'
      local cell1 = round(100 * `r(mean)', .01)
      qui sum is25 if _n == `i'
      local cell2 = round(100 * `r(mean)', .01)
      qui sum is50 if _n == `i'
      local cell3 = round(100 * `r(mean)', .01)
      qui sum is75 if _n == `i'
      local cell4 = round(100 * `r(mean)', .01)
      qui sum is100 if _n == `i'
      local cell5 = round(100 * `r(mean)', .01)
      putexcel C`counter' = ("`cell1'%") D`counter' = ("`cell2'%") /*
	    */E`counter' = ("`cell3'%") F`counter' = ("`cell4'%") /*
		*/G`counter' = ("`cell5'%")
    }
    qui sum obs if _n == 1
    local unweightednhs = round(`r(mean)', 1)
    qui sum obs if _n == 2
    local unweightednls = round(`r(mean)', 1)
    qui sum obs if _n == 3
    local unweightednhslm = round(`r(mean)', 1)
    qui sum obs if _n == 4
    local unweightednlslm = round(`r(mean)', 1)
    putexcel A21 = ("Weighted percentages in each cell. Unweighted N=`unweightednhs' in highly skilled condition and `unweightednls' in the low-skilled condition. In the labor market subsample, unweighted N=`unweightednhslm' and `unweightednlslm', respectively.")
restore

********************************************************************************
** Table D3: Question Wording and Survey Marginals for Measures of Personal
**   Economic Effects of Immigration, Low-Skilled Respondents
********************************************************************************

preserve
  keep if hs_dummy == 0
  *labor-market threat item, restricted to those working/looking or in HH with
  *  someone doing the same
  gen  rc_YL45_99 = rc_YL45_50 
  replace rc_YL45_99 = . if (YL45_10 != 1 & YL45_12 != 2 & YL45_17 != 1 & /*
    */YL45_18 != 2)
  keep YL45_49_69_treat rc_YL45_50 rc_YL45_99 rc_YL45_51 rc_YL45_52 /*
    */rc_YL45_49 rc_YL45_53 weight
  order YL45_49_69_treat rc_YL45_50 rc_YL45_99 rc_YL45_51 rc_YL45_52 /*
    */rc_YL45_49 rc_YL45_53
  gen id = _n
  reshape long rc_YL45_, i(id) j(qnum)
  gen is0 = rc_YL45_ == 0
  gen is25 = rc_YL45_ == .25
  gen is50 = rc_YL45_ == .50
  gen is75 = rc_YL45_ == .75
  gen is100 = rc_YL45_ == 1
  drop if rc_YL45_ == .
  gen obs = 1
  collapse (mean) is0 - is100 (sum) obs [aweight = weight], /*
    */by(qnum YL45_49_69_treat)
  replace qnum = 1 if qnum == 50
  replace qnum = 2 if qnum == 99 
  replace qnum = 3 if qnum == 51
  replace qnum = 4 if qnum == 52
  replace qnum = 5 if qnum == 49
  replace qnum = 6 if qnum == 53
  sort qnum YL45_49_69_treat 
  cl

  putexcel set Tables/TableD03_SurveyMarginals-EconomicConsequences-LS, replace
    putexcel A1 = ("Table D3: Question Wording and Survey Marginals for Measures of Personal Economic Effects of Immigration, Low-skilled Respondents")
    putexcel A2 = ("Question") B2 = ("Immigrant Type") C2 = ("Response Options")
    putexcel C3 = ("Strongly disagree") D3 = ("Somewhat disagree") /*
	  */E3 = ("Neither agree nor disagree") F3 = ("Somewhat agree") /*
	  */G3 = ("Strongly agree")
    putexcel A4 = ("Do you agree or disagree with the following statement: Increasing the number of [highly skilled/low-skilled] immigrants allowed to enter the U.S. will increase the chances that you or someone else in your household will lose their job or have their wages go down?")
   	putexcel C6 = ("Strongly disagree") E6 = ("Somewhat disagree") /*
	  */F6 = ("Neither agree nor disagree") G6 = ("Somewhat agree") /*
	  */H6 = ("Strongly agree")
    putexcel A7 = ("Households in Labor Market only: Do you agree or disagree with the following statement: Increasing the number of [highly skilled/low-skilled] immigrants allowed to enter the U.S. will increase the chances that you or someone else in your household will lose their job or have their wages go down?")
   	putexcel D9 = ("Decrease my taxes a lot") /*
	  */E9 = ("Decrease my taxes a little") /*
	  */F9 = ("Have no effect on my taxes") /*
	  */G9 = ("Increase my taxes a little") H9 = ("Increase my taxes a lot")
    putexcel A10 = ("Some people say that admitting more [highly skilled/low-skilled] immigrants to the United States will increase taxes because immigrants will place greater demands on government services, while others say that it will decrease taxes because these immigrants will pay more in taxes than they use in services.  What about you?  Admitting more [highly skilled/low-skilled] immigrants will...")
    putexcel D12 = ("Increase them greatly") /*
	  */E12 = ("Increase them somewhat") F12 = ("Have no effect") /*
	  */G12 = ("Reduce them somewhat") H12 = ("Reduce them greatly")
    putexcel A13 = ("Some people say that admitting more [highly skilled/low-skilled] immigrants to the United States will mean that more people take advantage of government services or receive government benefits, reducing what’s available to current citizens. What about you? How do you think that increasing the number of [highly skilled/low-skilled] immigrants will affect the government services available to you and your household?")
    putexcel D15 = ("Decrease my household's costs a lot") /*
	  */E15 = ("Decrease my household's costs a little") /*
	  */F15 = ("Have no effect on my household's costs") /*
	  */G15 = ("Increase my household's costs a little") /*
	  */H15 = ("Increase my household's costs a lot")
    putexcel A16 = ("One argument for admitting more [highly skilled/low-skilled] immigrants to the United States is that their work will reduce the costs of goods and services that other Americans use.  How do you think that increasing the number of [highly skilled/low-skilled] immigrants allowed to enter the U.S. will affect your household’s costs? It will...")
    putexcel D18 = ("The overall effect would be very positive for me") /*
	  */E18 = ("The overall effect would be somewhat positive for me") /*
	  */F18 = ("There would be no effect for me") /*
	  */G18 = ("The overall effect would be somewhat negative for me") /*
	  */H18 = ("The overall effect would be very negative for me")
    putexcel A19 = ("When you think about all of the potential positive and negative economic effects of increasing the number of  [highly skilled/low-skilled] immigrants coming to the United States, do you think the overall effect would be positive or negative for you and your household’s finances?")
    foreach i in 4 7 10 13 16 19 {
      local next = `i' + 1
      putexcel B`i' = ("Highly skilled")
      putexcel B`next' = ("Low-skilled")
    }
    forvalues i = 1/12 {
      if `i' == 1 | `i' == 2 {
        local counter = `i' + 3
      }
      if `i' == 3 | `i' == 4 {
        local counter = `i' + 4
      }
      if `i' == 5 | `i' == 6 {
        local counter = `i' + 5
      }
      if `i' == 7 | `i' == 8 {
        local counter = `i' + 6
      }
      if `i' == 9 | `i' == 10 {
        local counter = `i' + 7
      }
      if `i' == 11 | `i' == 12 {
        local counter = `i' + 8
      }
      qui sum is0 if _n == `i'
      local cell1 = round(100 * `r(mean)', .01)
      qui sum is25 if _n == `i'
      local cell2 = round(100 * `r(mean)', .01)
      qui sum is50 if _n == `i'
      local cell3 = round(100 * `r(mean)', .01)
      qui sum is75 if _n == `i'
      local cell4 = round(100 * `r(mean)', .01)
      qui sum is100 if _n == `i'
      local cell5 = round(100 * `r(mean)', .01)
      putexcel C`counter' = ("`cell1'%") D`counter' = ("`cell2'%") /*
	    */E`counter' = ("`cell3'%") F`counter' = ("`cell4'%") /*
		*/G`counter' = ("`cell5'%")
    }
    qui sum obs if _n == 1
    local unweightednhs = round(`r(mean)', 1)
    qui sum obs if _n == 2
    local unweightednls = round(`r(mean)', 1)
    qui sum obs if _n == 3
    local unweightednhslm = round(`r(mean)', 1)
    qui sum obs if _n == 4
    local unweightednlslm = round(`r(mean)', 1)
    putexcel A21 = ("Weighted percentages in each cell. Unweighted N=`unweightednhs' in highly skilled condition and `unweightednls' in the low-skilled condition. In the labor market subsample, unweighted N=`unweightednhslm' and `unweightednlslm', respectively.")
restore

********************************************************************************
** Table 2: Predicting Summary Economic Evaluations with Dimensions of Economic
**   Assessments
********************************************************************************

*standardized measures of economic consequences, (standardized within treatment)
foreach var of varlist rc_YL45_50 rc_YL45_51 rc_YL45_52 rc_YL45_49 rc_YL45_53 {
  local templabel : variable label `var'
  egen sd_`var' = std(`var') if YL45_49_69_treat == 1 & (YL45_10 == 1 | /*
    */YL45_12 == 2 | YL45_17 == 1 | YL45_18 == 2)
  egen temp = std(`var') if YL45_49_69_treat == 2 & (YL45_10 == 1 | /*
    */YL45_12 == 2 | YL45_17 == 1 | YL45_18 == 2)
  replace  sd_`var' = temp if YL45_49_69_treat == 2 & (YL45_10 == 1 | /*
    */YL45_12 == 2 | YL45_17 == 1 | YL45_18 == 2)
  drop temp
  label var sd_`var' "`templabel' (standardized)"
}

regress rc_YL45_53 rc_YL45_50 rc_YL45_51 rc_YL45_52 rc_YL45_49 female age /*
  */black white latino educ_hh ideo5 pid7 if YL45_49_69_treat == 1 & /*
  */(YL45_10 == 1 | YL45_12 == 2 | YL45_17 == 1 | YL45_18 == 2) /*
  */[aweight = weight], robust
outreg2 using Tables/Table02_PredictSummaryEconomicAttitudes, /*
  */lab alpha(0.001, 0.01, 0.05) dec(3) bracket aster(se) excel replace /*
  */ctitle("Full Labor Market Subsample, Highly Skilled Immigrants, Scaled (0-1)") /*
  */title("Table 2: Predicting Summary Economic Evaluations with Dimensions of Economic Assessments") /*
  */addnote("Note: Dependent variable is summary measure of household economic effects for admitting additional immigrants of specific type, scored so that more negative effects are larger values. Table entries are OLS coefficient estimates with robust (Huber/White) standard errors in brackets. Analysis uses analytic weights. In columns labeled 'Scaled (0-1),' economic attitude items are scored 0-1. In columns labeled 'Standardized Measure,' economic attitude items are recoded to have mean 0 and standard deviation 1 within sample used for that column's model estimates.")
outsum rc_YL45_53 rc_YL45_50 rc_YL45_51 rc_YL45_52 rc_YL45_49 female age /*
  */black white latino educ_hh ideo5 pid7 if YL45_49_69_treat == 1 & /*
  */(YL45_10 == 1 | YL45_12 == 2 | YL45_17 == 1 | YL45_18 == 2) /*
  */[aweight = weight] using Tables/TableE01_SummaryStatsWeightedMain, /*
  */bracket replace ctitle("Table 2, Highly Skilled Immigrants") /*
  */title("Table E1: Summary Statistics, Weighted, Main Text Analyses")
outsum rc_YL45_53 rc_YL45_50 rc_YL45_51 rc_YL45_52 rc_YL45_49 female age /*
  */black white latino educ_hh ideo5 pid7 if YL45_49_69_treat == 1 & /*
  */(YL45_10 == 1 | YL45_12 == 2 | YL45_17 == 1 | YL45_18 == 2) using /*
  */Tables/TableE02_SummaryStatsUnweightedMain, bracket replace /*
  */ctitle("Table 2, Highly Skilled Immigrants") /*
  */title("Table E2: Summary Statistics, Unweighted, Main Text Analyses")

regress sd_rc_YL45_53 sd_rc_YL45_50 sd_rc_YL45_51 sd_rc_YL45_52 sd_rc_YL45_49 /*
  */female age black white latino educ_hh ideo5 pid7 if YL45_49_69_treat == 1 /*
  */& (YL45_10 == 1 | YL45_12 == 2 | YL45_17 == 1 | YL45_18 == 2) /*
  */[aweight = weight], robust
outreg2 using Tables/Table02_PredictSummaryEconomicAttitudes, /*
  */lab alpha(0.001, 0.01, 0.05) dec(3) bracket aster(se) excel append /*
  */ctitle("Full Labor Market Subsample, Highly Skilled Immigrants, Standardized Measure")

regress rc_YL45_53 rc_YL45_50 rc_YL45_51 rc_YL45_52 rc_YL45_49 female age /*
  */black white latino educ_hh ideo5 pid7 if YL45_49_69_treat == 2 & /*
  */(YL45_10 == 1 | YL45_12 == 2 | YL45_17 == 1 | YL45_18 == 2) /*
  */[aweight = weight], robust
outreg2 using Tables/Table02_PredictSummaryEconomicAttitudes, /*
  */lab alpha(0.001, 0.01, 0.05) dec(3) bracket aster(se) excel append /*
  */ctitle("Full Labor Market Subsample, Low-skilled Immigrants, Scaled (0-1)")
outsum rc_YL45_53 rc_YL45_50 rc_YL45_51 rc_YL45_52 rc_YL45_49 female age /*
  */black white latino educ_hh ideo5 pid7 if YL45_49_69_treat == 2 & /*
  */(YL45_10 == 1 | YL45_12 == 2 | YL45_17 == 1 | YL45_18 == 2) /*
  */[aweight = weight] using Tables/TableE01_SummaryStatsWeightedMain, /*
  */bracket append ctitle("Table 2, Low-skilled Immigrants")
outsum rc_YL45_53 rc_YL45_50 rc_YL45_51 rc_YL45_52 rc_YL45_49 female age /*
  */black white latino educ_hh ideo5 pid7 if YL45_49_69_treat == 2 & /*
  */(YL45_10 == 1 | YL45_12 == 2 | YL45_17 == 1 | YL45_18 == 2) using /*
  */Tables/TableE02_SummaryStatsUnweightedMain, bracket append /*
  */ctitle("Table 2, Low-skilled Immigrants")

regress sd_rc_YL45_53 sd_rc_YL45_50 sd_rc_YL45_51 sd_rc_YL45_52 sd_rc_YL45_49 /*
  */female age black white latino educ_hh ideo5 pid7 if YL45_49_69_treat == 2 /*
  */& (YL45_10 == 1 | YL45_12 == 2 | YL45_17 == 1 | YL45_18 == 2) /*
  */[aweight = weight], robust
outreg2 using Tables/Table02_PredictSummaryEconomicAttitudes, /*
  */lab alpha(0.001, 0.01, 0.05) dec(3) bracket aster(se) excel append /*
  */ctitle("Full Labor Market Subsample, Low-skilled Immigrants, Standardized Measure")

regress rc_YL45_53 rc_YL45_50 rc_YL45_51 rc_YL45_52 rc_YL45_49 female age /*
  */black white latino educ_hh ideo5 pid7 if YL45_49_69_treat == 1 & /*
  */hs_dummy == 1 & (YL45_10 == 1 | YL45_12 == 2 | YL45_17 == 1 | /*
  */YL45_18 == 2) [aweight = weight], robust
outreg2 using Tables/Table02_PredictSummaryEconomicAttitudes, /*
  */lab alpha(0.001, 0.01, 0.05) dec(3) bracket aster(se) excel append /*
  */ctitle("Highly Skilled Subsample, Highly Skilled Immigrants, Scaled (0-1)")
outsum rc_YL45_53 rc_YL45_50 rc_YL45_51 rc_YL45_52 rc_YL45_49 female age /*
  */black white latino educ_hh ideo5 pid7 if YL45_49_69_treat == 1 & /*
  */hs_dummy == 1 & (YL45_10 == 1 | YL45_12 == 2 | YL45_17 == 1 | /*
  */YL45_18 == 2) [aweight = weight] using /*
  */Tables/TableE01_SummaryStatsWeightedMain, bracket append /*
  */ctitle("Table 2, R is Highly Skilled, Highly Skilled Immigrants")
outsum rc_YL45_53 rc_YL45_50 rc_YL45_51 rc_YL45_52 rc_YL45_49 female age /*
  */black white latino educ_hh ideo5 pid7 if YL45_49_69_treat == 1 & /*
  */hs_dummy == 1 & (YL45_10 == 1 | YL45_12 == 2 | YL45_17 == 1 | /*
  */YL45_18 == 2) using Tables/TableE02_SummaryStatsUnweightedMain, bracket /*
  */append ctitle("Table 2, R is Highly Skilled, Highly Skilled Immigrants")

regress rc_YL45_53 rc_YL45_50 rc_YL45_51 rc_YL45_52 rc_YL45_49 female age /*
  */black white latino educ_hh ideo5 pid7 if YL45_49_69_treat == 2 & /*
  */hs_dummy == 1 & (YL45_10 == 1 | YL45_12 == 2 | YL45_17 == 1 | /*
  */YL45_18 == 2)  [aweight = weight], robust
outreg2 using Tables/Table02_PredictSummaryEconomicAttitudes, /*
  */lab alpha(0.001, 0.01, 0.05) dec(3) bracket aster(se) excel append /*
  */ctitle("Highly Skilled Subsample, Low-skilled Immigrants, Scaled (0-1)")
outsum rc_YL45_53 rc_YL45_50 rc_YL45_51 rc_YL45_52 rc_YL45_49 female age /*
  */black white latino educ_hh ideo5 pid7 if YL45_49_69_treat == 2 & /*
  */hs_dummy == 1 & (YL45_10 == 1 | YL45_12 == 2 | YL45_17 == 1 | /*
  */YL45_18 == 2) [aweight = weight] using /*
  */Tables/TableE01_SummaryStatsWeightedMain, bracket append /*
  */ctitle("Table 2, R is Highly Skilled, Low-skilled Immigrants")
outsum rc_YL45_53 rc_YL45_50 rc_YL45_51 rc_YL45_52 rc_YL45_49 female age /*
  */black white latino educ_hh ideo5 pid7 if YL45_49_69_treat == 2 & /*
  */hs_dummy == 1 & (YL45_10 == 1 | YL45_12 == 2 | YL45_17 == 1 | /*
  */YL45_18 == 2) using Tables/TableE02_SummaryStatsUnweightedMain, bracket /*
  */append ctitle("Table 2, R is Highly Skilled, Low-skilled Immigrants")

regress rc_YL45_53 rc_YL45_50 rc_YL45_51 rc_YL45_52 rc_YL45_49 female age /*
  */black white latino educ_hh ideo5 pid7 if YL45_49_69_treat == 1 & /*
  */hs_dummy == 0 & (YL45_10 == 1 | YL45_12 == 2 | YL45_17 == 1 | /*
  */YL45_18 == 2) [aweight = weight], robust
outreg2 using Tables/Table02_PredictSummaryEconomicAttitudes, /*
  */lab alpha(0.001, 0.01, 0.05) dec(3) bracket aster(se) excel append /*
  */ctitle("Low-skilled Subsample, Highly Skilled Immigrants, Scaled (0-1)")
outsum rc_YL45_53 rc_YL45_50 rc_YL45_51 rc_YL45_52 rc_YL45_49 female age /*
  */black white latino educ_hh ideo5 pid7 if YL45_49_69_treat == 1 & /*
  */hs_dummy == 0 & (YL45_10 == 1 | YL45_12 == 2 | YL45_17 == 1 | /*
  */YL45_18 == 2) [aweight = weight] using /*
  */Tables/TableE01_SummaryStatsWeightedMain, bracket append /*
  */ctitle("Table 2, R is Low-skilled, Highly Skilled Immigrants")
outsum rc_YL45_53 rc_YL45_50 rc_YL45_51 rc_YL45_52 rc_YL45_49 female age /*
  */black white latino educ_hh ideo5 pid7 if YL45_49_69_treat == 1 & /*
  */hs_dummy == 0 & (YL45_10 == 1 | YL45_12 == 2 | YL45_17 == 1 | /*
  */YL45_18 == 2) using Tables/TableE02_SummaryStatsUnweightedMain, bracket /*
  */append ctitle("Table 2, R is Low-skilled, Highly Skilled Immigrants")

regress rc_YL45_53 rc_YL45_50 rc_YL45_51 rc_YL45_52 rc_YL45_49 female age /*
  */black white latino educ_hh ideo5 pid7 if YL45_49_69_treat == 2 & /*
  */hs_dummy == 0 & (YL45_10 == 1 | YL45_12 == 2 | YL45_17 == 1 | /*
  */YL45_18 == 2) [aweight = weight], robust
outreg2 using Tables/Table02_PredictSummaryEconomicAttitudes, /*
  */lab alpha(0.001, 0.01, 0.05) dec(3) bracket aster(se) excel append /*
  */ctitle("Low-Skilled Subsample, Low-skilled Immigrants, Scaled (0-1)")
outsum rc_YL45_53 rc_YL45_50 rc_YL45_51 rc_YL45_52 rc_YL45_49 female age /*
  */black white latino educ_hh ideo5 pid7 if YL45_49_69_treat == 2 & /*
  */hs_dummy == 0 & (YL45_10 == 1 | YL45_12 == 2 | YL45_17 == 1 | /*
  */YL45_18 == 2) [aweight = weight] using /*
  */Tables/TableE01_SummaryStatsWeightedMain, bracket append /*
  */ctitle("Table 2, R is Low-Skilled, Low-skilled Immigrants")
outsum rc_YL45_53 rc_YL45_50 rc_YL45_51 rc_YL45_52 rc_YL45_49 female age /*
  */black white latino educ_hh ideo5 pid7 if YL45_49_69_treat == 2 & /*
  */hs_dummy == 0 & (YL45_10 == 1 | YL45_12 == 2 | YL45_17 == 1 | /*
  */YL45_18 == 2) using Tables/TableE02_SummaryStatsUnweightedMain, bracket /*
  */append ctitle("Table 2, R is Low-Skilled, Low-skilled Immigrants")

drop sd_*

********************************************************************************
** Table F1: Predicting Summary Economic Evaluations with Dimensions of Economic
**   Assessments, Full Sample and Education as Skill Measure
********************************************************************************

*standardized measures of economic consequences, (standardized within treatment)
foreach var of varlist rc_YL45_50 rc_YL45_51 rc_YL45_52 rc_YL45_49 rc_YL45_53 {
  local templabel : variable label `var'
  egen sd_`var' = std(`var') if YL45_49_69_treat == 1
  egen temp = std(`var') if YL45_49_69_treat == 2
  replace  sd_`var' = temp if YL45_49_69_treat == 2
  drop temp
  label var sd_`var' "`templabel' (standardized)"
}

regress rc_YL45_53 rc_YL45_50 rc_YL45_51 rc_YL45_52 rc_YL45_49 female age /*
  */black white latino educ_hh ideo5 pid7 if YL45_49_69_treat == 1 /*
  */[aweight = weight], robust
outreg2 using Tables/TableF01_PredictSummaryEconomicAttitudes-FullEduc, /*
  */lab alpha(0.001, 0.01, 0.05) dec(3) bracket aster(se) excel replace /*
  */ctitle("All Respondents, Highly Skilled Immigrants, Scaled (0-1)") /*
  */title("Table F1: Predicting Summary Economic Evaluations with Dimensions of Economic Assessments, Full Sample and Education as Skill Measure")
outsum rc_YL45_53 rc_YL45_50 rc_YL45_51 rc_YL45_52 rc_YL45_49 female age /*
  */black white latino educ_hh ideo5 pid7 if YL45_49_69_treat == 1 /*
  */[aweight = weight] using Tables/TableE03_SummaryStatsWeightedAppendix, /*
  */bracket append ctitle("Table F1, Highly Skilled Immigrants, Full Sample")
outsum rc_YL45_53 rc_YL45_50 rc_YL45_51 rc_YL45_52 rc_YL45_49 female age /*
  */black white latino educ_hh ideo5 pid7 if YL45_49_69_treat == 1 using /*
  */Tables/TableE04_SummaryStatsUnweightedAppendix, bracket append /*
  */ctitle("Table F1, Highly Skilled Immigrants, Full Sample")

regress sd_rc_YL45_53 sd_rc_YL45_50 sd_rc_YL45_51 sd_rc_YL45_52 sd_rc_YL45_49 /*
  */female age black white latino educ_hh ideo5 pid7 if YL45_49_69_treat == 1 /*
  */[aweight = weight], robust
outreg2 using Tables/TableF01_PredictSummaryEconomicAttitudes-FullEduc, /*
  */lab alpha(0.001, 0.01, 0.05) dec(3) bracket aster(se) excel append /*
  */ctitle("All Respondents, Highly Skilled Immigrants, Standardized Measure")

regress rc_YL45_53 rc_YL45_50 rc_YL45_51 rc_YL45_52 rc_YL45_49 female age /*
  */black white latino educ_hh ideo5 pid7 if YL45_49_69_treat == 2 /*
  */[aweight = weight], robust
outreg2 using Tables/TableF01_PredictSummaryEconomicAttitudes-FullEduc, /*
  */lab alpha(0.001, 0.01, 0.05) dec(3) bracket aster(se) excel append /*
  */ctitle("All Respondents, Low-skilled Immigrants, Scaled (0-1)")
outsum rc_YL45_53 rc_YL45_50 rc_YL45_51 rc_YL45_52 rc_YL45_49 female age /*
  */black white latino educ_hh ideo5 pid7 if YL45_49_69_treat == 2 /*
  */[aweight = weight] using Tables/TableE03_SummaryStatsWeightedAppendix, /*
  */bracket append ctitle("Table F1, Low-skilled Immigrants, Full Sample")
outsum rc_YL45_53 rc_YL45_50 rc_YL45_51 rc_YL45_52 rc_YL45_49 female age /*
  */black white latino educ_hh ideo5 pid7 if YL45_49_69_treat == 2 using /*
  */Tables/TableE04_SummaryStatsUnweightedAppendix, bracket append /*
  */ctitle("Table F1, Low-skilled Immigrants, Full Sample")

regress sd_rc_YL45_53 sd_rc_YL45_50 sd_rc_YL45_51 sd_rc_YL45_52 sd_rc_YL45_49 /*
  */female age black white latino educ_hh ideo5 pid7 if YL45_49_69_treat == 2 /*
  */[aweight = weight], robust
outreg2 using Tables/TableF01_PredictSummaryEconomicAttitudes-FullEduc, /*
  */lab alpha(0.001, 0.01, 0.05) dec(3) bracket aster(se) excel append /*
  */ctitle("All Respondents, Low-skilled Immigrants, Standardized Measures")

regress rc_YL45_53 rc_YL45_50 rc_YL45_51 rc_YL45_52 rc_YL45_49 female age /*
  */black white latino ideo5 pid7 if YL45_49_69_treat == 1 & edu2 == 1 & /*
  */(YL45_10 == 1 | YL45_12 == 2 | YL45_17 == 1 | YL45_18 == 2) /*
  */[aweight = weight], robust
outreg2 using Tables/TableF01_PredictSummaryEconomicAttitudes-FullEduc, /*
  */lab alpha(0.001, 0.01, 0.05) dec(3) bracket aster(se) excel append /*
  */ctitle("Labor Market Subsample, High Education Subsample, Highly Skilled Immigrants, Scaled (0-1)")

regress rc_YL45_53 rc_YL45_50 rc_YL45_51 rc_YL45_52 rc_YL45_49 female age /*
  */black white latino ideo5 pid7 if YL45_49_69_treat == 2 & edu2 == 1 & /*
  */(YL45_10 == 1 | YL45_12 == 2 | YL45_17 == 1 | YL45_18 == 2) /*
  */[aweight = weight], robust
outreg2 using Tables/TableF01_PredictSummaryEconomicAttitudes-FullEduc, /*
  */lab alpha(0.001, 0.01, 0.05) dec(3) bracket aster(se) excel append /*
  */ctitle("Labor Market Subsample, High Education Subsample, Low-skilled Immigrants, Scaled (0-1)")

regress rc_YL45_53 rc_YL45_50 rc_YL45_51 rc_YL45_52 rc_YL45_49 female age /*
  */black white latino ideo5 pid7 if YL45_49_69_treat == 1 & edu2 == 0 & /*
  */(YL45_10 == 1 | YL45_12 == 2 | YL45_17 == 1 | YL45_18 == 2) /*
  */[aweight = weight], robust
outreg2 using Tables/TableF01_PredictSummaryEconomicAttitudes-FullEduc, /*
  */lab alpha(0.001, 0.01, 0.05) dec(3) bracket aster(se) excel append /*
  */ctitle("Labor Market Subsample, Low Education Subsample, Highly Skilled Immigrants, Scaled (0-1)")

regress rc_YL45_53 rc_YL45_50 rc_YL45_51 rc_YL45_52 rc_YL45_49 female age /*
  */black white latino ideo5 pid7 if YL45_49_69_treat == 2 & edu2 == 0 & /*
  */(YL45_10 == 1 | YL45_12 == 2 | YL45_17 == 1 | YL45_18 == 2) /*
  */[aweight = weight], robust
outreg2 using Tables/TableF01_PredictSummaryEconomicAttitudes-FullEduc, /*
  */lab alpha(0.001, 0.01, 0.05) dec(3) bracket aster(se) excel append /*
  */ctitle("Labor Market Subsample, Low Education Subsample, Low-skilled Immigrants, Scaled (0-1)")

drop sd_*

********************************************************************************
** Figure 2: Highly Skilled/Low-skilled Workers Evaluations of Personal Economic
**   Effects of Immigration by Immigrant Type
********************************************************************************

** Figure 2A
preserve
  *for labor market effects-question, replace it with missing if the person is
  *  not working, looking for work, or in a household with someone doing the
  *  same
  replace rc_YL45_50 = . if (YL45_10 != 1 & YL45_12 != 2 & YL45_17 != 1 & /*
    */YL45_18 != 2)
  keep if hs_dummy == 1

  *store variable labels for post-collapse
  foreach v of var * {
    local l`v' : variable label `v'
    if `"`l`v''"' == "" {
      local l`v' "`v'"
	}
  }

  *store p-values for difference of means tests in comparison of highly and low-
  *  skilled cases in last record, where the treatment variable will be set to .
  count
  local newobs = r(N) + 1
  set obs `newobs'
  qui foreach var of varlist rc_YL45_50 rc_YL45_51 rc_YL45_52 rc_YL45_49 /*
    */rc_YL45_53 `larger_conseq' `other_conseq' `wherefrom' {
    regress `var' YL45_49_69_treat if YL45_49_69_treat == 1 | /*
	*/YL45_49_69_treat == 2 [aweight = weight]
    replace `var' = (2 * ttail(e(df_r), abs(_b[YL45_49_69_treat] / /*
	  */_se[YL45_49_69_treat]))) if YL45_49_69_treat == .
    replace weight = 1  if YL45_49_69_treat == .
  }

  *store 95% confidence intervals  for means
  qui foreach var of varlist rc_YL45_50 rc_YL45_51 rc_YL45_52 rc_YL45_49 /*
    */rc_YL45_53 `larger_conseq' `other_conseq' `wherefrom' {
    ci means `var' if YL45_49_69_treat == 1  [aweight = weight]
    gen hici_`var' = r(ub) if YL45_49_69_treat == 1
    gen loci_`var' = r(lb) if YL45_49_69_treat == 1
    ci means `var' if YL45_49_69_treat == 2  [aweight = weight]
    replace hici_`var' = r(ub) if YL45_49_69_treat == 2
    replace loci_`var' = r(lb) if YL45_49_69_treat == 2
  }

  collapse (mean) rc_YL45_50 rc_YL45_51 rc_YL45_52 rc_YL45_49 rc_YL45_53 /*
    */`larger_conseq' `other_conseq' `wherefrom' hici_* loci_* /*
	*/[aweight = weight], by(YL45_49_69_treat)

  foreach v of var rc_YL45_50 rc_YL45_51 rc_YL45_52 rc_YL45_49 rc_YL45_53 /*
    */`larger_conseq' `other_conseq' `wherefrom' {
      label var `v' "`l`v''"
  }

  set obs 100
  gen temp = _n
  local varctr = 0
  gen outcome = .
  gen outcome_hici = .
  gen outcome_lowci = .
  gen outcomectr = .
  gen outcomeskill = .
  gen outcomeplocation = .
  gen outcomepvaluelabel = ""
  local graphhorizlabel = ""
  foreach var of varlist rc_YL45_50 rc_YL45_51 rc_YL45_52 rc_YL45_49 /*
    */rc_YL45_53 {
      if `varctr' != 0 {
        replace outcome = 0 in `varctr' 
        replace outcomectr = `varctr' in `varctr'
      }
      local varctr = `varctr' + 1
      *capture variable label and parse it into two parts based on word count
      local temp : variable label `var'
      local numwords = wordcount("`temp'")
      local firstlabel = ""
      local secondlabel = ""
      forval labelctr = 1(1)`numwords' {
        if `labelctr' <= int(`numwords' / 2) {
          local firstlabel = "`firstlabel'" + " " + word("`temp'", `labelctr')
        }
        else {
          local secondlabel = "`secondlabel'" + " " + word("`temp'", `labelctr')
        }
      }
      local firstlabel = trim("`firstlabel'")
      local secondlabel = trim("`secondlabel'")

      *p-value stored in location where the treatment indicator is missing
      qui sum `var' if YL45_49_69_treat == .
      replace outcomepvaluelabel = "  " + /*
	    */trim("p=" + string(`r(mean)', "%9.3f")) in `varctr'
      replace outcomeplocation = 1 in `varctr'
      replace outcomeplocation = .9 in `varctr' if /*
	    */int(`varctr' / 2) == (`varctr' / 2)
      sum `var' if YL45_49_69_treat == 1
      replace outcome = r(mean) in `varctr'
      sum hici_`var' if YL45_49_69_treat == 1
      replace outcome_hici = r(mean) in `varctr'
      sum loci_`var' if YL45_49_69_treat == 1
      replace outcome_lowci = r(mean) in `varctr'
      replace outcomectr = `varctr' in `varctr'
      replace outcomeskill = 1 in `varctr'
      local graphhorizlabel `"`graphhorizlabel' `varctr' "`firstlabel'""'
      local varctr = `varctr'+1
      sum `var' if YL45_49_69_treat == 2
      replace outcome = r(mean) in `varctr' 
      sum hici_`var' if YL45_49_69_treat == 2
      replace outcome_hici = r(mean) in `varctr'
      sum loci_`var' if YL45_49_69_treat == 2
      replace outcome_lowci = r(mean) in `varctr'
      replace outcomectr = `varctr' in `varctr'
      replace outcomeskill = 2 in `varctr'
      local graphhorizlabel `"`graphhorizlabel' `varctr' "`secondlabel'""' 
      local varctr = `varctr' + 1
  }

  gen temp2 = .05 if outcomeskill == 1 | outcomeskill == 2
  gen numastext = string(outcome, "%9.3f")

  twoway (bar outcome outcomectr if outcomeskill == 1) /*
    */(bar outcome outcomectr if outcomeskill == 2) /*
	*/(rcap outcome_hici outcome_lowci outcomectr, lcolor(black) /*
	*/msize(medium)) (scatter outcomeplocation outcomectr, /*
	*/mlabel(outcomepvaluelabel) msymbol(none) mlabsize(vsmall) /*
	*/mlabcolor(black) mlabposition(0)) (scatter temp2 outcomectr, /*
	*/mlabel(numastext) msymbol(none) mlabsize(vsmall) mlabcolor(black) /*
	*/mlabposition(0)), /*
	*/ytitle("Agreement (1 = Strongly Agree, 0 = Strongly Disagree)" " ", /*
	*/size(vsmall)) yscale(range(0 1)) ylabel(0(.25)1, labsize(vsmall)) /*
	*/xtitle("") yline(.5) xlabel(none, noticks labsize(vsmall) /*
	*/labcolor(black) angle(forty_five) labgap(small)) /*
	*/title("Panel A: Highly Skilled Respondents", size(vsmall)) legend(off) /*
	*/scheme(s1mono) name(hs_own_econeffects, replace) xsize(8.5) ysize(11) /*
	*/fysize(39)
restore

**Figure 2B
preserve
  *for labor market effects-question, replace it with missing if the person is
  *  not working, looking for work, or in a household with someone doing the
  *  same
  replace rc_YL45_50 = . if (YL45_10 != 1 & YL45_12 != 2 & YL45_17 != 1 & /*
    */YL45_18 != 2)
  keep if hs_dummy == 0

  *store variable labels for post-collapse
  foreach v of var * {
    local l`v' : variable label `v'
    if `"`l`v''"' == "" {
      local l`v' "`v'"
	}
  }

  *store p-values for difference of means tests in comparison of highly and low-
  *  skilled cases in last record, where the treatment variable will be set to .
  count
  local newobs = r(N) + 1
  set obs `newobs'
  qui foreach var of varlist rc_YL45_50 rc_YL45_51 rc_YL45_52 rc_YL45_49 /*
    */rc_YL45_53 `larger_conseq' `other_conseq' `wherefrom' {
      regress `var' YL45_49_69_treat if YL45_49_69_treat == 1 | /*
	    */YL45_49_69_treat == 2 [aweight = weight]
      replace `var' = (2 * ttail(e(df_r), abs(_b[YL45_49_69_treat] / /*
	    */_se[YL45_49_69_treat]))) if YL45_49_69_treat == .
      replace weight = 1  if YL45_49_69_treat == .
  }

  *store 95% confidence intervals for means
  qui foreach var of varlist rc_YL45_50 rc_YL45_51 rc_YL45_52 rc_YL45_49 /*
    */rc_YL45_53 `larger_conseq' `other_conseq' `wherefrom' {
      ci means `var' if YL45_49_69_treat == 1 [aweight = weight]
      gen hici_`var' = r(ub) if YL45_49_69_treat == 1
      gen loci_`var' = r(lb) if YL45_49_69_treat == 1
      ci means `var' if YL45_49_69_treat == 2 [aweight = weight]
      replace hici_`var' = r(ub) if YL45_49_69_treat == 2
      replace loci_`var' = r(lb) if YL45_49_69_treat == 2
  }

  collapse (mean) rc_YL45_50 rc_YL45_51 rc_YL45_52 rc_YL45_49 rc_YL45_53 /*
    */`larger_conseq' `other_conseq' `wherefrom' hici_* loci_* /*
	*/[aweight = weight], by(YL45_49_69_treat)

  foreach v of var rc_YL45_50 rc_YL45_51 rc_YL45_52 rc_YL45_49 rc_YL45_53 /*
    */`larger_conseq' `other_conseq' `wherefrom' {
      label var `v' "`l`v''"
  }

  set obs 100
  gen temp = _n
  local varctr = 0
  gen outcome = .
  gen outcome_hici = .
  gen outcome_lowci = .
  gen outcomectr = .
  gen outcomeskill = .
  gen outcomeplocation = .
  gen outcomepvaluelabel = ""
  local graphhorizlabel = ""
  foreach var of varlist rc_YL45_50 rc_YL45_51 rc_YL45_52 rc_YL45_49 /*
    */rc_YL45_53 {
      if `varctr' != 0 {
        replace outcome = 0 in `varctr' 
        replace outcomectr = `varctr' in `varctr'
      }
      local varctr = `varctr' + 1
      *capture variable label and parse it into two parts based on word count
      local temp : variable label `var'
      local numwords = wordcount("`temp'")
      local firstlabel = ""
      local secondlabel = ""
      forval labelctr = 1(1)`numwords' {
        if `labelctr' <= int(`numwords' / 2) {
          local firstlabel = "`firstlabel'" + " " + word("`temp'", `labelctr')
        }
        else {
          local secondlabel = "`secondlabel'" + " " + word("`temp'", `labelctr')
        }
      }
      local firstlabel = trim("`firstlabel'")
      local secondlabel = trim("`secondlabel'")

      *p-value stored in location where the treatment indicator is missing
      qui sum `var' if YL45_49_69_treat == .
      replace outcomepvaluelabel = "  " + /*
	    */trim("p=" + string(`r(mean)', "%9.3f")) in `varctr'
      replace outcomeplocation = 1 in `varctr'
      replace outcomeplocation = .9 in `varctr' if int(`varctr' / 2) == /*
	    */(`varctr' / 2)
      sum `var' if YL45_49_69_treat == 1
      replace outcome = r(mean) in `varctr'
      sum hici_`var' if YL45_49_69_treat == 1
      replace outcome_hici = r(mean) in `varctr'
      sum loci_`var' if YL45_49_69_treat == 1
      replace outcome_lowci = r(mean) in `varctr'
      replace outcomectr = `varctr' in `varctr'
      replace outcomeskill = 1 in `varctr'
      local graphhorizlabel `"`graphhorizlabel' `varctr' "`firstlabel'""' 
      local varctr = `varctr'+1
      sum `var' if YL45_49_69_treat == 2
      replace outcome = r(mean) in `varctr' 
      sum hici_`var' if YL45_49_69_treat == 2
      replace outcome_hici = r(mean) in `varctr'
      sum loci_`var' if YL45_49_69_treat == 2
      replace outcome_lowci = r(mean) in `varctr'
      replace outcomectr = `varctr' in `varctr'
      replace outcomeskill = 2 in `varctr'
      local graphhorizlabel `"`graphhorizlabel' `varctr' "`secondlabel'""' 
      local varctr = `varctr' + 1
  }

  gen temp2=.05 if  outcomeskill == 1 | outcomeskill == 2
  gen numastext = string(outcome, "%9.3f")

  twoway (bar outcome outcomectr if outcomeskill == 1) /*
    */(bar outcome outcomectr if outcomeskill == 2) /*
	*/(rcap outcome_hici outcome_lowci outcomectr, lcolor(black) /*
	*/msize(medium)) (scatter outcomeplocation outcomectr, /*
	*/mlabel(outcomepvaluelabel) msymbol(none) mlabsize(vsmall) /*
	*/mlabcolor(black) mlabposition(0)) (scatter temp2 outcomectr, /*
	*/mlabel(numastext) msymbol(none) mlabsize(vsmall) mlabcolor(black) /*
	*/mlabposition(0)), /*
	*/ytitle("Agreement (1 = Strongly Agree, 0 = Strongly Disagree)" " ", /*
	*/size(vsmall)) yscale(range(0 1)) ylabel(0(.25)1, labsize(vsmall)) /*
	*/xtitle("") yline(.5) xlabel(1.3 "Increase household" 1.7 /*
	*/"chance of job or wage loss" 4.3 "Increase" 4.7 "household taxes" 7.3 /*
	*/"Reduce household access" 7.7 "to government benefits" 10.3 /*
	*/"Increase household costs" 10.7 "of goods and services" 13.3 /*
	*/"Overall hurt" 13.7 "household finances", noticks labsize(vsmall) /*
	*/labcolor(black) angle(forty_five) labgap(small)) /*
	*/title("Panel B: Low-Skilled Respondents", size(vsmall)) /*
	*/legend(order(1 "Highly Skilled" 2 "Low-Skilled")) scheme(s1mono) /*
	*/name(ls_own_econeffects, replace) xsize(8.5) ysize(11)
restore

graph combine hs_own_econeffects ls_own_econeffects, ycommon xcommon cols(1) /*
  */xsize(8.5) ysize(11) scheme(s1mono)
graph export /*
  */Figures/Figure02_PersonalEconEffectsByOwnSkillAndImmigrantType.pdf, /*
  */as(pdf) replace
graph drop _all

*************************
** discussion of Figure 2
*************************

*labor market threat difference between low- and highly skilled respondents for
*  highly skilled immigrants
regress rc_YL45_50 hs_dummy [aweight = weight] if (YL45_10 == 1 | /*
  */YL45_12 == 2 | YL45_17 == 1 | YL45_18 == 2) & YL45_49_69_treat == 1
*labor market threat difference between low- and highly skilled respondents for
*  low-skilled immigrants
regress rc_YL45_50 hs_dummy [aweight = weight] if (YL45_10 == 1 | /*
  */YL45_12 == 2 | YL45_17 == 1 | YL45_18 == 2) & YL45_49_69_treat == 2
*fiscal burden difference between low- and highly skilled respondents for highly
*  skilled immigrants
regress rc_YL45_51 hs_dummy [aweight = weight] if YL45_49_69_treat == 1
*fiscal burden difference between low- and highly skilled respondents for
*  low-skilled immigrants
regress rc_YL45_51 hs_dummy [aweight = weight] if YL45_49_69_treat == 2
*access to benefits difference between low- and highly skilled respondents for
*  low-skilled immigrants
regress rc_YL45_52 hs_dummy [aweight = weight] if YL45_49_69_treat == 2
*price effects difference between low- and highly skilled respondents for
*  low-skilled immigrants
regress rc_YL45_49 hs_dummy [aweight = weight] if YL45_49_69_treat == 2
*hh finances difference between low- and highly skilled respondents for highly
*  skilled immigrants
regress rc_YL45_53 hs_dummy [aweight = weight] if (YL45_10 == 1 | /*
  */YL45_12 == 2 | YL45_17 == 1 | YL45_18 == 2) & YL45_49_69_treat == 1
*hh finances difference between low- and highly skilled respondents for
*  low-skilled immigrants
regress rc_YL45_53 hs_dummy [aweight = weight] if (YL45_10 == 1 | /*
  */YL45_12 == 2 | YL45_17 == 1 | YL45_18 == 2) & YL45_49_69_treat == 2

gen treat = YL45_49_69_treat == 1
*labor market threat difference between low- and highly skilled immigrants for
*  highly skilled respondents
regress rc_YL45_50 treat [aweight = weight] if (YL45_10 == 1 | YL45_12 == 2 | /*
  */YL45_17 == 1 | YL45_18 == 2) & hs_dummy == 1
*labor market threat difference between low- and highly skilled immigrants for
*  low-skilled respondents
regress rc_YL45_50 treat [aweight = weight] if (YL45_10 == 1 | YL45_12 == 2 | /*
  */YL45_17 == 1 | YL45_18 == 2) & hs_dummy == 0
*fiscal burden difference between low- and highly skilled immigrants for highly
*  skilled respondents
regress rc_YL45_51 treat [aweight = weight] if hs_dummy == 1
*fiscal burden difference between low- and highly skilled immigrants for
*  low-skilled respondents
regress rc_YL45_51 treat [aweight = weight] if hs_dummy == 0
*access to benefits difference between low- and highly skilled immigrants for
*  highly skilled respondents
regress rc_YL45_52 treat [aweight = weight] if hs_dummy == 1
*access to benefits difference between low- and highly skilled immigrants for
*  low-skilled respondents
regress rc_YL45_52 treat [aweight = weight] if hs_dummy == 0
*price effects difference between low- and highly skilled immigrants for highly
*  skilled respondents
regress rc_YL45_49 treat [aweight = weight] if hs_dummy == 1
*price effects difference between low- and highly skilled immigrants for
*  low-skilled respondents
regress rc_YL45_49 treat [aweight = weight] if hs_dummy == 0
*hh finances difference between low- and highly skilled immigrants for highly
*  skilled respondents
regress rc_YL45_53 treat [aweight = weight] if hs_dummy == 1
*hh finances difference between low- and highly skilled immigrants for
*  low-skilled respondents
regress rc_YL45_53 treat [aweight = weight] if hs_dummy == 0
drop treat

********************************************************************************
** Table G1: Relationship Between Skill Level and Labor Threat, Based on
**   Training
********************************************************************************

*no training, highly skilled respondent, highly skilled immigrant treatment
sum rc_YL45_50 if YL45_49_69_treat == 1 & hs_dummy == 1 & (YL45_10 == 1 | /*
  */YL45_12 == 2 | YL45_17 == 1 | YL45_18 == 2) & (skill_treat == 1 | /*
  */skill_treat == 2) [aweight = weight]
local rh_ih_nt_n = `r(N)'
local rh_ih_nt_nw = `r(sum_w)'
local rh_ih_nt_mean = round(`r(mean)', .001)
local rh_ih_nt_sd = round(`r(sd)', .001)
*no training, highly skilled respondent, low-skilled immigrant treatment
sum rc_YL45_50 if YL45_49_69_treat == 2 & hs_dummy == 1 & (YL45_10 == 1 | /*
  */YL45_12 == 2 | YL45_17 == 1 | YL45_18 == 2) & (skill_treat == 1 | /*
  */skill_treat == 2) [aweight = weight]
local rh_il_nt_n = `r(N)'
local rh_il_nt_nw = `r(sum_w)'
local rh_il_nt_mean = round(`r(mean)', .001)
local rh_il_nt_sd = round(`r(sd)', .001)
*no training, low-skilled respondent, highly skilled immigrant treatment
sum rc_YL45_50 if YL45_49_69_treat == 1 & hs_dummy == 0 & (YL45_10 == 1 | /*
  */YL45_12 == 2 | YL45_17 == 1 | YL45_18 == 2) & (skill_treat == 1 | /*
  */skill_treat == 2) [aweight = weight]
local rl_ih_nt_n = `r(N)'
local rl_ih_nt_nw = `r(sum_w)'
local rl_ih_nt_mean = round(`r(mean)', .001)
local rl_ih_nt_sd = round(`r(sd)', .001)
*no training, low-skilled respondent, low-skilled immigrant treatment
sum rc_YL45_50 if YL45_49_69_treat == 2 & hs_dummy == 0 & (YL45_10 == 1 | /*
  */YL45_12 == 2 | YL45_17 == 1 | YL45_18 == 2) & (skill_treat == 1 | /*
  */skill_treat == 2) [aweight = weight]
local rl_il_nt_n = `r(N)'
local rl_il_nt_nw = `r(sum_w)'
local rl_il_nt_mean = round(`r(mean)', .001)
local rl_il_nt_sd = round(`r(sd)', .001)
*training, highly skilled respondent, highly skilled immigrant treatment
sum rc_YL45_50 if YL45_49_69_treat == 1 & hs_dummy == 1 & (YL45_10 == 1 | /*
  */YL45_12 == 2 | YL45_17 == 1 | YL45_18 == 2) & (skill_treat == 4 | /*
  */skill_treat == 5 | skill_treat == 6 | skill_treat == 7) [aweight = weight]
local rh_ih_tr_n = `r(N)'
local rh_ih_tr_nw = `r(sum_w)'
local rh_ih_tr_mean = round(`r(mean)', .001)
local rh_ih_tr_sd = round(`r(sd)', .001)
*training, highly skilled respondent, low-skilled immigrant treatment
sum rc_YL45_50 if YL45_49_69_treat == 2 & hs_dummy == 1 & (YL45_10 == 1 | /*
  */YL45_12 == 2 | YL45_17 == 1 | YL45_18 == 2) & (skill_treat == 4 | /*
  */skill_treat == 5 | skill_treat == 6 | skill_treat == 7) [aweight = weight]
local rh_il_tr_n = `r(N)'
local rh_il_tr_nw = `r(sum_w)'
local rh_il_tr_mean = round(`r(mean)', .001)
local rh_il_tr_sd = round(`r(sd)', .001)
*training, low-skilled respondent, highly skilled immigrant treatment
sum rc_YL45_50 if YL45_49_69_treat == 1 & hs_dummy == 0 & (YL45_10 == 1 | /*
  */YL45_12 == 2 | YL45_17 == 1 | YL45_18 == 2) & (skill_treat == 4 | /*
  */skill_treat == 5 | skill_treat == 6 | skill_treat == 7) [aweight = weight]
local rl_ih_tr_n = `r(N)'
local rl_ih_tr_nw = `r(sum_w)'
local rl_ih_tr_mean = round(`r(mean)', .001)
local rl_ih_tr_sd = round(`r(sd)', .001)
*training, low-skilled respondent, low-skilled immigrant treatment
sum rc_YL45_50 if YL45_49_69_treat == 2 & hs_dummy == 0 & (YL45_10 == 1 | /*
  */YL45_12 == 2 | YL45_17 == 1 | YL45_18 == 2) & (skill_treat == 4 | /*
  */skill_treat == 5 | skill_treat == 6 | skill_treat == 7) [aweight = weight]
local rl_il_tr_n = `r(N)'
local rl_il_tr_nw = `r(sum_w)'
local rl_il_tr_mean = round(`r(mean)', .001)
local rl_il_tr_sd = round(`r(sd)', .001)

*ttest: highly skilled respondents, highly skilled immigrant treatment, training
*  vs. no training
ttesti `rh_ih_nt_n' `rh_ih_nt_mean' `rh_ih_nt_sd' `rh_ih_tr_n' /*
  */`rh_ih_tr_mean' `rh_ih_tr_sd'
*ttest: highly skilled respondents, low-skilled immigrant treatment, training
*  vs. no training
ttesti `rh_il_nt_n' `rh_il_nt_mean' `rh_il_nt_sd' `rh_il_tr_n' /*
  */`rh_il_tr_mean' `rh_il_tr_sd'
*ttest: low-skilled respondents, highly skilled immigrant treatment, training
*  vs. no training
ttesti `rl_ih_nt_n' `rl_ih_nt_mean' `rl_ih_nt_sd' `rl_ih_tr_n' /*
  */`rl_ih_tr_mean' `rl_ih_tr_sd'
*ttest: low-skilled respondents, low-skilled immigrant treatment, training
*  vs. no training
ttesti `rl_il_nt_n' `rl_il_nt_mean' `rl_il_nt_sd' `rl_il_tr_n' /*
  */`rl_il_tr_mean' `rl_il_tr_sd'

*weighted percentage of highly skilled respondents, no training conditions
local rh_pct_nt = round(100 * (`rh_ih_nt_nw' + `rh_il_nt_nw') / /*
  */(`rh_ih_nt_nw' + `rh_il_nt_nw' + `rl_ih_nt_nw' + `rl_il_nt_nw'), .01)
*weighted percentage of highly skilled respondents, training conditions
local rh_pct_tr = round(100 * (`rh_ih_tr_nw' + `rh_il_tr_nw') / /*
  */(`rh_ih_tr_nw' + `rh_il_tr_nw' + `rl_ih_tr_nw' + `rl_il_tr_nw'), .01)

putexcel set Tables/TableG01_TrainingSkillLevelTreatmentMeans, replace
  putexcel A1 = ("Table G1: Means by Skill Level of Respondent, Skill Level of Immigrant, and Training about Definition of Skill Level")
  putexcel A2 = ("Did Not Receive Training")
  putexcel B3 = ("Labor Market Threat")
  putexcel B4 = ("Highly Skilled Immigrants") C4 = ("Low-skilled Immigrants")
  putexcel A5 = ("Highly Skilled Respondents") B5 = ("`rh_ih_nt_mean'") /*
    */C5 = ("`rh_il_nt_mean'")
  putexcel B6 = ("[`rh_ih_nt_sd']") C6 = ("[`rh_il_nt_sd']")
  putexcel A7 = ("Low-skilled Respondents") B7 = ("`rl_ih_nt_mean'") /*
    */C7 = ("`rl_il_nt_mean'")
  putexcel B8 = ("[`rl_ih_nt_sd']") C8 = ("[`rl_il_nt_sd']")
  putexcel A9 = ("Note: `rh_pct_nt' percent of respondents self-classify as highly skilled workers.")
  putexcel A11 = ("Received Training")
  putexcel B12 = ("Labor Market Threat")
  putexcel B13 = ("Highly Skilled Immigrants") C13 = ("Low-skilled Immigrants")
  putexcel A14 = ("Highly Skilled Respondents") B14 = ("`rh_ih_tr_mean'") /*
    */C14 = ("`rh_il_tr_mean'")
  putexcel B15 = ("[`rh_ih_tr_sd']") C15 = ("[`rh_il_tr_sd']")
  putexcel A16 = ("Low-skilled Respondents") B16 = ("`rl_ih_tr_mean'") /*
    */C16 = ("`rl_il_tr_mean'")
  putexcel B17 = ("[`rl_ih_tr_sd']") C17 = ("[`rl_il_tr_sd']")
  putexcel A18 = ("Note: `rh_pct_tr' percent of respondents self-classify as highly skilled workers.")

********************************************************************************
** endnote 19: labor market threat analyses, restricted to cases in which only
**   the respondent him- or herself is in the labor market
********************************************************************************

bysort hs_dummy : regress rc_YL45_50 YL45_49_69_treat [aweight = weight] if /*
  */(YL45_10 == 1 | YL45_12 == 2) & hs_dummy != .

********************************************************************************
** Table H1: Predicting Components of Cultural Threat Index by Immigrant Type
********************************************************************************

gen usedpost = 0
replace usedpost = 1 if oppose_hs == . & oppose_pst_hs != . & /*
  */YL45_49_69_treat == 1
replace oppose_hs = oppose_pst_hs if oppose_hs == . & oppose_pst_hs != .
replace usedpost = 1 if oppose_ls == . & oppose_pst_ls != . & /*
  */YL45_49_69_treat == 2
replace oppose_ls = oppose_pst_ls if oppose_ls == . & oppose_pst_ls != .
label var usedpost "Survey Question Placement (0 = Beginning, 1 = End)"

*create factor score
factor rc_YL45_56a rc_YL45_56e rc_YL45_56h rc_YL45_56j rc_YL45_56n /*
  */rc_YL45_56p, pcf
predict factscore
*rescale factor score to be on same 0-1 interval as all other measures
sum factscore
replace factscore = factscore - `r(min)'
sum factscore
replace factscore = factscore / `r(max)'
label var factscore "Cultural Threat Index Factor Score (0-1)"
sum factscore

gen immigrant_is_lowskilled = YL45_49_69_treat == 2
label var immigrant_is_lowskilled /*
  */"Immigrant is low-skilled (1=yes, 0=highly skilled)"

foreach var of varlist rc_YL45_56a rc_YL45_56e rc_YL45_56h rc_YL45_56j /*
  */rc_YL45_56n rc_YL45_56p {
    local varlab : variable label `var'
    regress `var' immigrant_is_lowskilled female age black white latino /*
      */educ_hh ideo5 pid7 [aweight = weight]
    if "`var'" == "rc_YL45_56a" {
      outreg2 using Tables/TableH01_EffectofSkillOnCulturalThreat, /*
        */lab alpha(0.001, 0.01, 0.05) dec(3) bracket aster(se) excel replace /*
        */ctitle("`varlab'") /*
        */title("Table H1: Predicting Components of Cultural Threat Index by Immigrant Type") /*
        */addnote("Note: Dependent variable in each column is scaled from 0 to 1, with higher values corresponding to greater agreement with the statement. Table entries are OLS coefficient estimates with robust (Huber/White) standard errors in brackets. Analysis uses analytic weights.")
    }
    else {
      outreg2 using Tables/TableH01_EffectofSkillOnCulturalThreat, /*
        */lab alpha(0.001, 0.01, 0.05) dec(3) bracket aster(se) excel /*
        */append ctitle("`varlab'")
    }
}
drop immigrant_is_lowskilled

********************************************************************************
** endnote 21: Discussion of Table 2 results
********************************************************************************

*test difference in correlation between labor market concerns and overall
*  economic assessments between those assigned to highly skilled and those
*  assigned to low-skilled immigrant conditions, highly skilled subsample
*  (Table 2, columns 5 and 6)
regress rc_YL45_53 i.YL45_49_69_treat##c.rc_YL45_50 /*
  */i.YL45_49_69_treat##c.rc_YL45_51 i.YL45_49_69_treat##c.rc_YL45_52 /*
  */i.YL45_49_69_treat##c.rc_YL45_49 i.YL45_49_69_treat##i.female /*
  */i.YL45_49_69_treat##c.age i.YL45_49_69_treat##i.black /*
  */i.YL45_49_69_treat##i.white i.YL45_49_69_treat##i.latino /*
  */i.YL45_49_69_treat##c.educ_hh i.YL45_49_69_treat##c.ideo5 /*
  */i.YL45_49_69_treat##c.pid7 if hs_dummy == 1 & (YL45_10 == 1 | /*
  */YL45_12 == 2 | YL45_17 == 1 | YL45_18 == 2) [aweight = weight], robust

regress rc_YL45_53 i.YL45_49_69_treat##c.rc_YL45_50 /*
  */i.YL45_49_69_treat##c.rc_YL45_51 i.YL45_49_69_treat##c.rc_YL45_52 /*
  */i.YL45_49_69_treat##c.rc_YL45_49 i.YL45_49_69_treat##i.female /*
  */i.YL45_49_69_treat##c.age i.YL45_49_69_treat##i.black /*
  */i.YL45_49_69_treat##i.white i.YL45_49_69_treat##i.latino /*
  */i.YL45_49_69_treat##c.educ_hh i.YL45_49_69_treat##c.ideo5 /*
  */i.YL45_49_69_treat##c.pid7 if hs_dummy == 0 & (YL45_10 == 1 | /*
  */YL45_12 == 2 | YL45_17 == 1 | YL45_18 == 2) [aweight = weight], robust

********************************************************************************
** Table 3: Predicting Overall Immigration Policy Attitudes by Immigrant Type
**   with Personal Economic, Sociotropic Economic, and Cultural Concerns
********************************************************************************

qui regress oppose_hs oppose_ls rc_YL45_53 rc_YL45_61 factscore usedpost /*
  */female age black white latino educ_hh ideo5 pid7 [aweight = weight]
gen useme = 1 if e(sample)

regress oppose_hs rc_YL45_53 usedpost female age black white latino educ_hh /*
  */ideo5 pid7 if YL45_49_69_treat == 1 & useme == 1 [aweight = weight], robust
outreg2 using Tables/Table03_PersonalEconomicsVsStuff, /*
  */lab alpha(0.001, 0.01, 0.05) dec(3) bracket aster(se) excel replace /*
  */ctitle("Opposition to Admitting More Highly Skilled Immigrants (0-1) (1)") /*
  */title("Table 3: Predicting Overall Immigration Policy Attitudes by Immigrant Type with Personal Economic, Sociotropic Economic, and Cultural Concerns") /*
  */addnote("Note: Dependent variable is summary measure of opposition to admitting immigrants of specific type, scored so that strong opposition is coded 1 and strong support is coded 0. Table entries are OLS coefficient estimates with robust (Huber/White) standard errors in brackets. Analysis uses analytic weights.")
regress oppose_hs rc_YL45_53 rc_YL45_61 factscore usedpost female age black /*
  */white latino educ_hh ideo5 pid7 if YL45_49_69_treat == 1 & useme == 1 /*
  */[aweight = weight], robust
outreg2 using Tables/Table03_PersonalEconomicsVsStuff, /*
  */lab alpha(0.001, 0.01, 0.05) dec(3) bracket aster(se) excel append /*
  */ctitle("Opposition to Admitting More Highly Skilled Immigrants (0-1) (2)")
regress oppose_hs oppose_ls rc_YL45_53 rc_YL45_61 factscore usedpost female /*
  */age black white latino educ_hh ideo5 pid7 if YL45_49_69_treat == 1 & /*
  */useme == 1 [aweight = weight], robust
outreg2 using Tables/Table03_PersonalEconomicsVsStuff, /*
  */lab alpha(0.001, 0.01, 0.05) dec(3) bracket aster(se) excel append /*
  */ctitle("Opposition to Admitting More Highly Skilled Immigrants (0-1) (3)")
outsum oppose_hs oppose_ls rc_YL45_53 rc_YL45_61 factscore usedpost female /*
  */age black white latino educ_hh ideo5 pid7 if YL45_49_69_treat == 1 & /*
  */useme == 1 [aweight = weight] using /*
  */Tables/TableE01_SummaryStatsWeightedMain, bracket append /*
  */ctitle("Table 3, Highly Skilled Immigrant Treatment Cases")
outsum oppose_hs oppose_ls rc_YL45_53 rc_YL45_61 factscore usedpost female /*
  */age black white latino educ_hh ideo5 pid7 if YL45_49_69_treat == 1 & /*
  */useme == 1 using Tables/TableE02_SummaryStatsUnweightedMain, bracket /*
  */append ctitle("Table 3, Highly Skilled Immigrant Treatment Cases")

regress oppose_ls rc_YL45_53 usedpost female age black white latino educ_hh /*
  */ideo5 pid7 if YL45_49_69_treat == 2 & useme == 1 [aweight = weight], robust
outreg2 using Tables/Table03_PersonalEconomicsVsStuff, /*
  */lab alpha(0.001, 0.01, 0.05) dec(3) bracket aster(se) excel append /*
  */ctitle("Opposition to Admitting More Low-skilled Immigrants (0-1) (1)")
regress oppose_ls rc_YL45_53 rc_YL45_61 factscore usedpost female age black /*
  */white latino educ_hh ideo5 pid7 if YL45_49_69_treat == 2 & useme == 1 /*
  */[aweight = weight], robust
outreg2 using Tables/Table03_PersonalEconomicsVsStuff, /*
  */lab alpha(0.001, 0.01, 0.05) dec(3) bracket aster(se) excel append /*
  */ctitle("Opposition to Admitting More Low-skilled Immigrants (0-1) (2)")
regress oppose_ls oppose_hs rc_YL45_53 rc_YL45_61 factscore usedpost female /*
  */age black white latino educ_hh ideo5 pid7 if YL45_49_69_treat == 2 & /*
  */useme == 1 [aweight = weight], robust
outreg2 using tables/Table03_PersonalEconomicsVsStuff, /*
  */lab alpha(0.001, 0.01, 0.05) dec(3) bracket aster(se) excel append /*
  */ctitle("Opposition to Admitting More Low-skilled Immigrants (0-1) (3)")
outsum oppose_hs oppose_ls rc_YL45_53 rc_YL45_61 factscore usedpost female /*
  */age black white latino educ_hh ideo5 pid7 if YL45_49_69_treat == 2 & /*
  */useme == 1 [aweight = weight] using /*
  */Tables/TableE01_SummaryStatsWeightedMain, bracket append /*
  */ctitle("Table 3, Low-skilled Immigrant Treatment Cases")
outsum oppose_hs oppose_ls rc_YL45_53 rc_YL45_61 factscore usedpost female /*
  */age black white latino educ_hh ideo5 pid7 if YL45_49_69_treat == 2 & /*
  */useme == 1 using Tables/TableE02_SummaryStatsUnweightedMain, bracket /*
  */append ctitle("Table 3, Low-skilled Immigrant Treatment Cases")

gen outcome = oppose_ls if YL45_49_69_treat == 2
replace outcome = oppose_hs if YL45_49_69_treat == 1
label var outcome "Opposition to admitting immigrant of type (0-1)"
gen immigrant_is_lowskilled = YL45_49_69_treat == 2
label var immigrant_is_lowskilled /*
  */"Immigrant is low-skilled (1=yes, 0=highly skilled)"

regress outcome immigrant_is_lowskilled usedpost female age black white /*
  */latino educ_hh ideo5 pid7 if useme == 1 [aweight = weight], robust
outreg2 using Tables/Table03_PersonalEconomicsVsStuff, /*
  */lab alpha(0.001, 0.01, 0.05) dec(3) bracket aster(se) excel append /*
  */ctitle("Pooled Opposition to Admitting Immigrants of Type (0-1) (1)")
regress outcome rc_YL45_53 rc_YL45_61 factscore immigrant_is_lowskilled /*
  */usedpost female age black white latino educ_hh ideo5 pid7 if useme == 1 /*
  */[aweight = weight], robust
outreg2 using Tables/Table03_PersonalEconomicsVsStuff, /*
  */lab alpha(0.001, 0.01, 0.05) dec(3) bracket aster(se) excel append /*
  */ctitle("Pooled Opposition to Admitting Immigrants of Type (0-1) (2)")
outsum outcome rc_YL45_53 rc_YL45_61 immigrant_is_lowskilled factscore /*
  */usedpost female age black white latino educ_hh ideo5 pid7 if useme == 1 /*
  */[aweight = weight] using Tables/TableE01_SummaryStatsWeightedMain, /*
  */bracket append ctitle("Table 3, Pooled")
outsum outcome rc_YL45_53 rc_YL45_61 immigrant_is_lowskilled factscore /*
  */usedpost female age black white latino educ_hh ideo5 pid7 if useme == 1 /*
  */using Tables/TableE02_SummaryStatsUnweightedMain, bracket append /*
  */ctitle("Table 3, Pooled")

********************************************************************************
** endnote 25: discussion of Table 3 results
********************************************************************************

regress oppose_hs usedpost female age black white latino educ_hh ideo5 pid7 /*
  */if YL45_49_69_treat == 1 & useme == 1 [aweight = weight], robust

regress oppose_hs rc_YL45_53 usedpost female age black white latino educ_hh /*
  */ideo5 pid7 if YL45_49_69_treat == 1 & useme == 1 [aweight = weight], robust

********************************************************************************
** endnote 26: discussion of Table 3 results
********************************************************************************

regress oppose_ls usedpost female age black white latino educ_hh ideo5 pid7 /*
  */if YL45_49_69_treat == 2 & useme == 1 [aweight = weight], robust

regress oppose_ls rc_YL45_53 usedpost female age black white latino educ_hh /*
  */ideo5 pid7 if YL45_49_69_treat == 2 & useme == 1 [aweight = weight], robust

********************************************************************************
** in-text discussion of Table 3 results
********************************************************************************

qui regress oppose_hs oppose_ls rc_YL45_53 rc_YL45_61 factscore usedpost /*
  */female age black white latino educ_hh ideo5 pid7 if YL45_49_69_treat == 1 /*
  */& useme == 1 [aweight = weight], robust
gen hs_ls_same = 0 if e(sample)
replace hs_ls_same = 1 if oppose_hs == oppose_ls & e(sample)
sum hs_ls_same

********************************************************************************
** Table I1: Predicting Overall Immigration Policy Attitudes by Immigrant Type
**   with Personal Economic, Sociotropic Economic, and Cultural Concerns, Early
**   Policy Question Subset
********************************************************************************

regress oppose_hs rc_YL45_53 female age black white latino educ_hh ideo5 pid7 /*
  */if usedpost == 0 & YL45_49_69_treat == 1 & useme == 1 [aweight = weight], /*
  */robust
outreg2 using Tables/TableI01_PersonalEconomicsVsStuffEarlySurvey, /*
  */lab alpha(0.001, 0.01, 0.05) dec(3) bracket aster(se) excel replace /*
  */ctitle("Opposition to Admitting More Highly Skilled Immigrants (0-1) (1)") /*
  */title("Table I1: Predicting Overall Immigration Policy Attitudes by Immigrant Type with Personal Economic, Sociotropic Economic, and Cultural Concerns, Early Policy Question Subset")
regress oppose_hs rc_YL45_53 rc_YL45_61 factscore female age black white /*
  */latino educ_hh ideo5 pid7 if usedpost == 0 & YL45_49_69_treat == 1 & /*
  */useme == 1 [aweight = weight], robust
outreg2 using Tables/TableI01_PersonalEconomicsVsStuffEarlySurvey, /*
  */lab alpha(0.001, 0.01, 0.05) dec(3) bracket aster(se) excel append /*
  */ctitle("Opposition to Admitting More Highly Skilled Immigrants (0-1) (2)")
regress oppose_hs oppose_ls rc_YL45_53 rc_YL45_61 factscore female age black /*
  */white latino educ_hh ideo5 pid7 if usedpost == 0 & YL45_49_69_treat == 1 /*
  */& useme == 1 [aweight = weight], robust
outreg2 using Tables/TableI01_PersonalEconomicsVsStuffEarlySurvey, /*
  */lab alpha(0.001, 0.01, 0.05) dec(3) bracket aster(se) excel append /*
  */ctitle("Opposition to Admitting More Highly Skilled Immigrants (0-1) (3)")
outsum oppose_hs oppose_ls rc_YL45_53 rc_YL45_61 factscore female age black /*
  */white latino educ_hh ideo5 pid7 if usedpost == 0 & YL45_49_69_treat == 1 /*
  */& useme == 1 [aweight = weight] using /*
  */Tables/TableE03_SummaryStatsWeightedAppendix, bracket append /*
  */ctitle("Table I1, Highly Skilled Immigrants")
outsum oppose_hs oppose_ls rc_YL45_53 rc_YL45_61 factscore female age black /*
  */white latino educ_hh ideo5 pid7 if usedpost == 0 & YL45_49_69_treat == 1 /*
  */& useme == 1 using Tables/TableE04_SummaryStatsUnweightedAppendix, /*
  */bracket append ctitle("Table I1, Highly Skilled Immigrants")

regress oppose_ls rc_YL45_53 female age black white latino educ_hh ideo5 pid7 /*
  */if usedpost == 0 & YL45_49_69_treat == 2 & useme == 1 [aweight = weight], /*
  */robust
outreg2 using Tables/TableI01_PersonalEconomicsVsStuffEarlySurvey, /*
  */lab alpha(0.001, 0.01, 0.05) dec(3) bracket aster(se) excel append /*
  */ctitle("Opposition to Admitting More Low-skilled Immigrants (0-1) (1)")
regress oppose_ls rc_YL45_53 rc_YL45_61 factscore female age black white /*
  */latino educ_hh ideo5 pid7 if usedpost == 0 & YL45_49_69_treat == 2 & /*
  */useme == 1 [aweight = weight], robust
outreg2 using Tables/TableI01_PersonalEconomicsVsStuffEarlySurvey, /*
  */lab alpha(0.001, 0.01, 0.05) dec(3) bracket aster(se) excel append /*
  */ctitle("Opposition to Admitting More Low-skilled Immigrants (0-1) (2)")
regress oppose_ls oppose_hs rc_YL45_53 rc_YL45_61 factscore female age black /*
  */white latino educ_hh ideo5 pid7 if usedpost == 0 & YL45_49_69_treat == 2 /*
  */& useme == 1 [aweight = weight], robust
outreg2 using Tables/TableI01_PersonalEconomicsVsStuffEarlySurvey, /*
  */lab alpha(0.001, 0.01, 0.05) dec(3) bracket aster(se) excel append /*
  */ctitle("Opposition to Admitting More Low-skilled Immigrants (0-1) (3)")
outsum oppose_ls oppose_hs rc_YL45_53 rc_YL45_61 factscore female age black /*
  */white latino educ_hh ideo5 pid7 if usedpost == 0 & YL45_49_69_treat == 2 /*
  */& useme == 1 [aweight = weight] using /*
  */Tables/TableE03_SummaryStatsWeightedAppendix, bracket append /*
  */ctitle("Table I1, Low-skilled Immigrants")
outsum oppose_ls oppose_hs rc_YL45_53 rc_YL45_61 factscore female age black /*
  */white latino educ_hh ideo5 pid7 if usedpost == 0 & YL45_49_69_treat == 2 /*
  */& useme == 1 using Tables/TableE04_SummaryStatsUnweightedAppendix, /*
  */bracket append ctitle("Table I1, Low-skilled Immigrants")

regress outcome immigrant_is_lowskilled female age black white latino /*
  */educ_hh ideo5 pid7 if usedpost == 0 & useme == 1 [aweight = weight], robust
outreg2 using Tables/TableI01_PersonalEconomicsVsStuffEarlySurvey, /*
  */lab alpha(0.001, 0.01, 0.05) dec(3) bracket aster(se) excel append /*
  */ctitle("Pooled, Opposition to Immigrants of Type (0-1) (1)")
regress outcome rc_YL45_53 rc_YL45_61 factscore immigrant_is_lowskilled /*
  */female age black white latino educ_hh ideo5 pid7 if usedpost == 0 & /*
  */useme == 1 [aweight = weight], robust
outreg2 using Tables/TableI01_PersonalEconomicsVsStuffEarlySurvey, /*
  */lab alpha(0.001, 0.01, 0.05) dec(3) bracket aster(se) excel append /*
  */ctitle("Pooled, Opposition to Immigrants of Type (0-1) (2)")
outsum outcome rc_YL45_53 rc_YL45_61 factscore immigrant_is_lowskilled female /*
  */age black white latino educ_hh ideo5 pid7 if usedpost == 0 & useme == 1 /*
  */[aweight = weight] using Tables/TableE03_SummaryStatsWeightedAppendix, /*
  */bracket append ctitle("Table I1, Pooled")
outsum outcome rc_YL45_53 rc_YL45_61 factscore immigrant_is_lowskilled female /*
  */age black white latino educ_hh ideo5 pid7 if usedpost == 0 & useme == 1 /*
  */using Tables/TableE04_SummaryStatsUnweightedAppendix, bracket append /*
  */ctitle("Table H1, Pooled")

********************************************************************************
** Table H2: Predicting Overall Immigration Policy Attitudes by Immigrant Type
**   with Personal Economic, Sociotropic Economic, and Cultural Concerns, Late
**   Policy Question Subset
********************************************************************************

regress oppose_hs rc_YL45_53 female age black white latino educ_hh ideo5 pid7 /*
  */if usedpost == 1 & YL45_49_69_treat == 1 & useme == 1 [aweight = weight], /*
  */robust
outreg2 using Tables/TableI02_PersonalEconomicsVsStuffLateSurvey, /*
  */lab alpha(0.001, 0.01, 0.05) dec(3) bracket aster(se) excel replace /*
  */ctitle("Opposition to Admitting More Highly Skilled Immigrants (0-1) (1)") /*
  */title("Table I2: Predicting Overall Immigration Policy Attitudes by Immigrant Type with Personal Economic, Sociotropic Economic, and Cultural Concerns, Late Policy Question Subset")
regress oppose_hs rc_YL45_53 rc_YL45_61 factscore female age black white /*
  */latino educ_hh ideo5 pid7 if usedpost == 1 & YL45_49_69_treat == 1 & /*
  */useme == 1 [aweight = weight], robust
outreg2 using Tables/TableI02_PersonalEconomicsVsStuffLateSurvey, /*
  */lab alpha(0.001, 0.01, 0.05) dec(3) bracket aster(se) excel append /*
  */ctitle("Opposition to Admitting More Highly Skilled Immigrants (0-1) (2)")
regress oppose_hs oppose_ls rc_YL45_53 rc_YL45_61 factscore female age black /*
  */white latino educ_hh ideo5 pid7 if usedpost == 1 & YL45_49_69_treat == 1 /*
  */& useme == 1 [aweight = weight], robust
outreg2 using Tables/TableI02_PersonalEconomicsVsStuffLateSurvey, /*
  */lab alpha(0.001, 0.01, 0.05) dec(3) bracket aster(se) excel append /*
  */ctitle("Opposition to Admitting More Highly Skilled Immigrants (0-1) (3)")
outsum oppose_hs oppose_ls rc_YL45_53 rc_YL45_61 factscore female age black /*
  */white latino educ_hh ideo5 pid7 if usedpost == 1 & YL45_49_69_treat == 1 /*
  */& useme == 1 [aweight = weight] using /*
  */Tables/TableE03_SummaryStatsWeightedAppendix, bracket append /*
  */ctitle("Table I2, Highly Skilled Immigrants")
outsum oppose_hs oppose_ls rc_YL45_53 rc_YL45_61 factscore female age black /*
  */white latino educ_hh ideo5 pid7 if usedpost == 1 & YL45_49_69_treat == 1 /*
  */& useme == 1 using Tables/TableE04_SummaryStatsUnweightedAppendix, /*
  */bracket append ctitle("Table I2, Highly Skilled Immigrants")

regress oppose_ls rc_YL45_53 female age black white latino educ_hh ideo5 pid7 /*
  */if usedpost == 1 & YL45_49_69_treat == 2 & useme == 1 [aweight = weight], /*
  */robust
outreg2 using Tables/TableI02_PersonalEconomicsVsStuffLateSurvey, /*
  */lab alpha(0.001, 0.01, 0.05) dec(3) bracket aster(se) excel append /*
  */ctitle("Opposition to Admitting More Low-skilled Immigrants (0-1) (1)")
regress oppose_ls rc_YL45_53 rc_YL45_61 factscore female age black white /*
  */latino educ_hh ideo5 pid7 if usedpost == 1 & YL45_49_69_treat == 2 & /*
  */useme == 1 [aweight = weight], robust
outreg2 using Tables/TableI02_PersonalEconomicsVsStuffLateSurvey, /*
  */lab alpha(0.001, 0.01, 0.05) dec(3) bracket aster(se) excel append /*
  */ctitle("Opposition to Admitting More Low-skilled Immigrants (0-1) (2)")
regress oppose_ls oppose_hs rc_YL45_53 rc_YL45_61 factscore female age black /*
  */white latino educ_hh ideo5 pid7 if usedpost == 1 & YL45_49_69_treat == 2 /*
  */& useme == 1 [aweight = weight], robust
outreg2 using Tables/TableI02_PersonalEconomicsVsStuffLateSurvey, /*
  */lab alpha(0.001, 0.01, 0.05) dec(3) bracket aster(se) excel append /*
  */ctitle("Opposition to Admitting More Low-skilled Immigrants (0-1) (3)")
outsum oppose_ls oppose_hs rc_YL45_53 rc_YL45_61 factscore female age black /*
  */white latino educ_hh ideo5 pid7 if usedpost == 1 & YL45_49_69_treat == 2 /*
  */& useme == 1 [aweight = weight] using /*
  */Tables/TableE03_SummaryStatsWeightedAppendix, bracket append /*
  */ctitle("Table I2, Low-skilled Immigrants")
outsum oppose_ls oppose_hs rc_YL45_53 rc_YL45_61 factscore female age black /*
  */white latino educ_hh ideo5 pid7 if usedpost == 1 & YL45_49_69_treat == 2 /*
  */& useme == 1 using Tables/TableE04_SummaryStatsUnweightedAppendix, /*
  */bracket append ctitle("Table I2, Low-skilled Immigrants")

regress outcome immigrant_is_lowskilled female age black white latino educ_hh /*
  */ideo5 pid7 if usedpost == 1 & useme == 1 [aweight = weight], robust
outreg2 using Tables/TableI02_PersonalEconomicsVsStuffLateSurvey, /*
  */lab alpha(0.001, 0.01, 0.05) dec(3) bracket aster(se) excel append /*
  */ctitle("Pooled, Opposition to Immigrants of Type (0-1) (1)")
regress outcome rc_YL45_53 rc_YL45_61 factscore immigrant_is_lowskilled /*
  */female age black white latino educ_hh ideo5 pid7 if usedpost == 1 & /*
  */useme == 1 [aweight = weight], robust
outreg2 using Tables/TableI02_PersonalEconomicsVsStuffLateSurvey, /*
  */lab alpha(0.001, 0.01, 0.05) dec(3) bracket aster(se) excel append /*
  */ctitle("Pooled, Opposition to Immigrants of Type (0-1) (2)")
outsum outcome rc_YL45_53 rc_YL45_61 factscore immigrant_is_lowskilled female /*
  */age black white latino educ_hh ideo5 pid7 if usedpost == 1 & useme == 1 /*
  */[aweight = weight] using Tables/TableE03_SummaryStatsWeightedAppendix, /*
  */bracket append ctitle("Table I2, Pooled")
outsum outcome rc_YL45_53 rc_YL45_61 factscore immigrant_is_lowskilled female /*
  */age black white latino educ_hh ideo5 pid7 if usedpost == 1 & useme == 1 /*
  */using Tables/TableE04_SummaryStatsUnweightedAppendix, bracket append /*
  */title("Table I2, Pooled")

drop useme
drop outcome

********************************************************************************
** Table J1: Predicting Overall Immigration Policy Attitudes by Immigrant Type
**   with Personal Economic, Sociotropic Economic, Cultural Concerns
**   (Alternative (Single Cultural Threat Item)
********************************************************************************

foreach var of varlist rc_YL45_53 rc_YL45_57 rc_YL45_61 {
  local templabel : variable label `var'
  egen sd_`var' = std(`var') 
  egen temp = std(`var') 
  replace  sd_`var' = temp 
  drop temp
  label var sd_`var' "`templabel'"
}

qui regress oppose_hs oppose_ls rc_YL45_53 rc_YL45_57 rc_YL45_61 usedpost /*
  */female age black white latino educ_hh ideo5 pid7 if YL45_49_69_treat == 1 /*
  */[aweight = weight], robust
gen useme = 1 if e(sample)

regress oppose_hs rc_YL45_53 usedpost female age black white latino educ_hh /*
  */ideo5 pid7 if YL45_49_69_treat == 1 & useme == 1 [aweight = weight], robust
outreg2 using Tables/TableJ01_PersonalSociotropicCultural, /*
  */lab alpha(0.001, 0.01, 0.05) dec(3) bracket aster(se) excel replace /*
  */ctitle("Opposition to Admitting More Highly Skilled Immigrants (0-1) (1)") /*
  */title("Table J1: Predicting Overall Immigration Policy Attitudes by Immigrant Type with Personal Economic, Sociotropic Economic, and Cultural Concerns (Single Cultural Threat Item)")
regress oppose_hs rc_YL45_53 rc_YL45_57 rc_YL45_61 usedpost female age black /*
  */white latino educ_hh ideo5 pid7 if YL45_49_69_treat == 1 & useme == 1 /*
  */[aweight = weight], robust
outreg2 using Tables/TableJ01_PersonalSociotropicCultural, /*
  */lab alpha(0.001, 0.01, 0.05) dec(3) bracket aster(se) excel append /*
  */ctitle("Opposition to Admitting More Highly Skilled Immigrants (0-1) (2)")
regress oppose_hs oppose_ls rc_YL45_53 rc_YL45_57 rc_YL45_61 usedpost female /*
  */age black white latino educ_hh ideo5 pid7 if YL45_49_69_treat == 1 & /*
  */useme == 1 [aweight = weight], robust
outreg2 using Tables/TableJ01_PersonalSociotropicCultural, /*
  */lab alpha(0.001, 0.01, 0.05) dec(3) bracket aster(se) excel append /*
  */ctitle("Opposition to Admitting More Highly Skilled Immigrants (0-1) (3)")
outsum oppose_hs oppose_ls rc_YL45_53 rc_YL45_57 rc_YL45_61 usedpost female /*
  */age black white latino educ_hh ideo5 pid7 if YL45_49_69_treat == 1 & /*
  */useme == 1 [aweight = weight] using /*
  */Tables/TableE03_SummaryStatsWeightedAppendix, bracket append /*
  */ctitle("Table J1, Highly Skilled Immigrants") 
outsum oppose_hs oppose_ls rc_YL45_53 rc_YL45_57 rc_YL45_61 usedpost female /*
  */age black white latino educ_hh ideo5 pid7 if YL45_49_69_treat == 1 & /*
  */useme == 1 using Tables/TableE04_SummaryStatsUnweightedAppendix, bracket /*
  */append ctitle("Table J1, Highly Skilled Immigrants")
drop useme

qui regress oppose_ls oppose_hs rc_YL45_53 rc_YL45_57 rc_YL45_61 usedpost /*
  */female age black white latino educ_hh ideo5 pid7 if YL45_49_69_treat == 2 /*
  */[aweight=weight], robust
gen useme = 1 if e(sample)

regress oppose_ls rc_YL45_53 usedpost female age black white latino educ_hh /*
  */ideo5 pid7 if YL45_49_69_treat == 2 & useme == 1 [aweight = weight], robust
outreg2 using Tables/TableJ01_PersonalSociotropicCultural, /*
  */lab alpha(0.001, 0.01, 0.05) dec(3) bracket aster(se) excel append /*
  */ctitle("Opposition to Admitting More Low-skilled Immigrants (0-1) (1)")
regress oppose_ls rc_YL45_53 rc_YL45_57 rc_YL45_61 usedpost female age black /*
  */white latino educ_hh ideo5 pid7 if YL45_49_69_treat == 2 & useme == 1 /*
  */[aweight=weight], robust
outreg2 using Tables/TableJ01_PersonalSociotropicCultural, /*
  */lab alpha(0.001, 0.01, 0.05) dec(3) bracket aster(se) excel append /*
  */ctitle("Opposition to Admitting More Low-skilled Immigrants (0-1) (2)")
regress oppose_ls oppose_hs rc_YL45_53 rc_YL45_57 rc_YL45_61 usedpost female /*
  */age black white latino educ_hh ideo5 pid7 if YL45_49_69_treat == 2 & /*
  */useme == 1 [aweight = weight], robust
outreg2 using Tables/TableJ01_PersonalSociotropicCultural, /*
  */lab alpha(0.001, 0.01, 0.05) dec(3) bracket aster(se) excel append /*
  */ctitle("Opposition to Admitting More Low-skilled Immigrants (0-1) (3)")
outsum oppose_ls oppose_hs rc_YL45_53 rc_YL45_57 rc_YL45_61 usedpost female /*
  */age black white latino educ_hh ideo5 pid7 if YL45_49_69_treat == 2 & /*
  */useme == 1 [aweight = weight] using /*
  */Tables/TableE03_SummaryStatsWeightedAppendix, bracket append /*
  */ctitle("Table J1, Low-skilled Immigrants")
outsum oppose_ls oppose_hs rc_YL45_53 rc_YL45_57 rc_YL45_61 usedpost female /*
  */age black white latino educ_hh ideo5 pid7 if YL45_49_69_treat == 2 & /*
  */useme == 1 using Tables/TableE04_SummaryStatsUnweightedAppendix, bracket /*
  */append ctitle("Table J1, Low-skilled Immigrants")
drop useme

gen outcome = oppose_ls if YL45_49_69_treat == 2
replace outcome = oppose_hs if YL45_49_69_treat == 1
label var outcome "Opposition to admitting immigrant of type (0-1)"

qui regress outcome rc_YL45_53 rc_YL45_57 rc_YL45_61 immigrant_is_lowskilled /*
  */usedpost female age black white latino educ_hh ideo5 pid7 /*
  */[aweight=weight], robust
gen useme = 1 if e(sample)

regress outcome immigrant_is_lowskilled usedpost female age black white /*
  */latino educ_hh ideo5 pid7 if useme == 1 [aweight = weight], robust
outreg2 using Tables/TableJ01_PersonalSociotropicCultural, /*
  */lab alpha(0.001, 0.01, 0.05) dec(3) bracket aster(se) excel append /*
  */ctitle("Pooled, Opposition to Admitting Immigrants of Type (0-1) (1)")
regress outcome rc_YL45_53 rc_YL45_57 rc_YL45_61 immigrant_is_lowskilled /*
  */usedpost female age black white latino educ_hh ideo5 pid7 if useme == 1 /*
  */[aweight=weight], robust
outreg2 using tables/TableJ01_PersonalSociotropicCultural, /*
  */lab alpha(0.001, 0.01, 0.05) dec(3) bracket aster(se) excel append /*
  */ctitle("Pooled, Opposition to Admitting Immigrants of Type (0-1) (2)")
outsum outcome rc_YL45_53 rc_YL45_57 rc_YL45_61 immigrant_is_lowskilled /*
  */usedpost female age black white latino educ_hh ideo5 pid7 if useme == 1 /*
  */[aweight = weight] using Tables/TableE03_SummaryStatsWeightedAppendix, /*
  */bracket append ctitle("Table J1, Pooled")
outsum outcome rc_YL45_53 rc_YL45_57 rc_YL45_61 immigrant_is_lowskilled /*
  */usedpost female age black white latino educ_hh ideo5 pid7 if useme == 1 /*
  */using Tables/TableE04_SummaryStatsUnweightedAppendix, bracket append /*
  */ctitle("Table J1, Pooled")
drop sd_*

drop useme
drop outcome

********************************************************************************
** Table J2: Predicting Overall Immigration Policy Attitudes by Immigrant Type
**   with Personal Economic, Sociotropic Economic, Cultural Concerns
**   (Alternative (Both Cultural Threat Items)
********************************************************************************

foreach var of varlist rc_YL45_53 rc_YL45_57 rc_YL45_61 {
  local templabel : variable label `var'
  egen sd_`var' = std(`var')
  egen temp = std(`var')
  replace sd_`var' = temp
  drop temp
  label var sd_`var' "`templabel'"
}

qui regress oppose_hs oppose_ls rc_YL45_53 rc_YL45_57 rc_YL45_61 factscore /*
  */usedpost female age black white latino educ_hh ideo5 pid7 if /*
  */YL45_49_69_treat == 1 [aweight = weight], robust
gen useme = 1 if e(sample)

regress oppose_hs rc_YL45_53 usedpost female age black white latino educ_hh /*
  */ideo5 pid7 if YL45_49_69_treat == 1 & useme == 1 [aweight = weight], robust
outreg2 using Tables/TableJ02_PersonalSociotropicCultural, /*
  */lab alpha(0.001, 0.01, 0.05) dec(3) bracket aster(se) excel replace /*
  */ctitle("Opposition to Admitting More Highly Skilled Immigrants (0-1) (1)") /*
  */title("Table J2: Predicting Overall Immigration Policy Attitudes by Immigrant Type with Personal Economic, Sociotropic Economic, and Cultural Concerns (Both Cultural Threat Items)")
regress oppose_hs rc_YL45_53 rc_YL45_57 rc_YL45_61 factscore usedpost female /*
  */age black white latino educ_hh ideo5 pid7 if YL45_49_69_treat == 1 & /*
  */useme == 1 [aweight = weight], robust
outreg2 using Tables/TableJ02_PersonalSociotropicCultural, /*
  */lab alpha(0.001, 0.01, 0.05) dec(3) bracket aster(se) excel append /*
  */ctitle("Opposition to Admitting More Highly Skilled Immigrants (0-1) (2)")
regress oppose_hs oppose_ls rc_YL45_53 rc_YL45_57 rc_YL45_61 factscore /*
  */usedpost female age black white latino educ_hh ideo5 pid7 if /*
  */YL45_49_69_treat == 1 & useme == 1 [aweight = weight], robust
outreg2 using Tables/TableJ02_PersonalSociotropicCultural, /*
  */lab alpha(0.001, 0.01, 0.05) dec(3) bracket aster(se) excel append /*
  */ctitle("Opposition to Admitting More Highly Skilled Immigrants (0-1) (3)")
outsum oppose_hs oppose_ls rc_YL45_53 rc_YL45_57 rc_YL45_61 factscore /*
  */usedpost female age black white latino educ_hh ideo5 pid7 if /*
  */YL45_49_69_treat == 1 & useme == 1 [aweight = weight] using /*
  */Tables/TableE03_SummaryStatsWeightedAppendix, bracket append /*
  */ctitle("Table J2, Highly Skilled Immigrants")
outsum oppose_hs oppose_ls rc_YL45_53 rc_YL45_57 rc_YL45_61 factscore /*
  */usedpost female age black white latino educ_hh ideo5 pid7 if /*
  */YL45_49_69_treat == 1 & useme == 1 using /*
  */Tables/TableE04_SummaryStatsUnweightedAppendix, bracket append /*
  */ctitle("Table J2, Highly Skilled Immigrants")
drop useme

qui regress oppose_ls oppose_hs rc_YL45_53 rc_YL45_57 rc_YL45_61 factscore /*
  */usedpost female age black white latino educ_hh ideo5 pid7 if /*
  */YL45_49_69_treat == 2 [aweight = weight], robust
gen useme = 1 if e(sample)

regress oppose_ls rc_YL45_53 usedpost female age black white latino educ_hh /*
  */ideo5 pid7 if YL45_49_69_treat == 2 & useme == 1 [aweight = weight], robust
outreg2 using Tables/TableJ02_PersonalSociotropicCultural, /*
  */lab alpha(0.001, 0.01, 0.05) dec(3) bracket aster(se) excel append /*
  */ctitle("Opposition to Admitting More Low-skilled Immigrants (0-1) (1)")
regress oppose_ls rc_YL45_53 rc_YL45_57 rc_YL45_61 factscore usedpost female /*
  */age black white latino educ_hh ideo5 pid7 if YL45_49_69_treat == 2 & /*
  */useme == 1 [aweight = weight], robust
outreg2 using Tables/TableJ02_PersonalSociotropicCultural, /*
  */lab alpha(0.001, 0.01, 0.05) dec(3) bracket aster(se) excel append /*
  */ctitle("Opposition to Admitting More Low-skilled Immigrants (0-1) (2)")
regress oppose_ls oppose_hs rc_YL45_53 rc_YL45_57 rc_YL45_61 factscore /*
  */usedpost female age black white latino educ_hh ideo5 pid7 if /*
  */YL45_49_69_treat == 2 & useme == 1 [aweight =weight], robust
outreg2 using Tables/TableJ02_PersonalSociotropicCultural, /*
  */lab alpha(0.001, 0.01, 0.05) dec(3) bracket aster(se) excel append /*
  */ctitle("Opposition to Admitting More Low-skilled Immigrants (0-1) (3)")
outsum oppose_ls oppose_hs rc_YL45_53 rc_YL45_57 rc_YL45_61 factscore /*
  */usedpost female age black white latino educ_hh ideo5 pid7 if /*
  */YL45_49_69_treat == 2 & useme == 1 [aweight = weight] using /*
  */Tables/TableE03_SummaryStatsWeightedAppendix, bracket append /*
  */ctitle("Table J2, Low-skilled Immigrants")
outsum oppose_ls oppose_hs rc_YL45_53 rc_YL45_57 rc_YL45_61 factscore /*
  */usedpost female age black white latino educ_hh ideo5 pid7 if /*
  */YL45_49_69_treat == 2 & useme == 1 using /*
  */Tables/TableE04_SummaryStatsUnweightedAppendix, bracket append /*
  */ctitle("Table J2, Low-skilled Immigrants")
drop useme

gen outcome = oppose_ls if YL45_49_69_treat == 2
replace outcome = oppose_hs if YL45_49_69_treat == 1
label var outcome "Opposition to admitting immigrant of type (0-1)"

qui regress outcome rc_YL45_53 rc_YL45_57 rc_YL45_61 factscore /*
  */immigrant_is_lowskilled usedpost female age black white latino educ_hh /*
  */ideo5 pid7 [aweight = weight], robust
gen useme = 1 if e(sample)

regress outcome immigrant_is_lowskilled usedpost female age black white /*
  */latino educ_hh ideo5 pid7 if useme == 1 [aweight = weight], robust
outreg2 using Tables/TableJ02_PersonalSociotropicCultural, /*
  */lab alpha(0.001, 0.01, 0.05) dec(3) bracket aster(se) excel append /*
  */ctitle("Pooled, Opposition to Admitting Immigrants of Type (0-1) (1)")
regress outcome rc_YL45_53 rc_YL45_57 rc_YL45_61 factscore /*
  */immigrant_is_lowskilled usedpost female age black white latino educ_hh /*
  */ideo5 pid7 if useme == 1 [aweight = weight], robust
outreg2 using Tables/TableJ02_PersonalSociotropicCultural, /*
  */lab alpha(0.001, 0.01, 0.05) dec(3) bracket aster(se) excel append /*
  */ctitle("Pooled, Opposition to Admitting Immigrants of Type (0-1) (2)")
outsum outcome rc_YL45_53 rc_YL45_57 rc_YL45_61 factscore /*
  */immigrant_is_lowskilled usedpost female age black white latino educ_hh /*
  */ideo5 pid7 if useme == 1 [aweight = weight] using /*
  */Tables/TableE03_SummaryStatsWeightedAppendix, bracket append /*
  */ctitle("Table J2, Pooled")
outsum outcome rc_YL45_53 rc_YL45_57 rc_YL45_61 factscore /*
  */immigrant_is_lowskilled usedpost female age black white latino educ_hh /*
  */ideo5 pid7 if useme == 1 using /*
  */Tables/TableE04_SummaryStatsUnweightedAppendix, bracket append /*
  */ctitle("Table J2, Pooled")
drop sd_*
drop useme
drop outcome

********************************************************************************
** Table J3: Predicting Overall Immigration Policy Attitudes by Immigrant Type
**   with Personal Economic and Sociotropic Economic Concerns, Low Cultural
**   Threat Respondents
********************************************************************************

egen mean_cultural_threat = mean(factscore)
gen low_cultural_threat = factscore < mean_cultural_threat

qui regress oppose_hs oppose_ls rc_YL45_53 rc_YL45_61 factscore usedpost /*
  */female age black white latino educ_hh ideo5 pid7 [aweight = weight]
gen useme = 1 if e(sample)

regress oppose_hs rc_YL45_53 usedpost female age black white latino educ_hh /*
  */ideo5 pid7 if low_cultural_threat == 1 & YL45_49_69_treat == 1 & /*
  */useme == 1 [aweight = weight], robust
outreg2 using Tables/TableJ03_PersonalSociotropicLowCulturalThreat, /*
  */lab alpha(0.001, 0.01, 0.05) dec(3) bracket aster(se) excel replace /*
  */ctitle("Opposition to Admitting More Highly Skilled Immigrants (0-1) (1)") /*
  */title("Table J3: Predicting Overall Immigration Policy Attitudes by Immigrant Type with Personal Economic and Sociotropic Economic Concerns, Low Cultural Threat Respondents")
regress oppose_hs rc_YL45_53 rc_YL45_61 factscore usedpost female age black /*
  */white latino educ_hh ideo5 pid7 if low_cultural_threat == 1 & /*
  */YL45_49_69_treat == 1 & useme == 1 [aweight = weight], robust
outreg2 using Tables/TableJ03_PersonalSociotropicLowCulturalThreat, /*
  */lab alpha(0.001, 0.01, 0.05) dec(3) bracket aster(se) excel append /*
  */ctitle("Opposition to Admitting More Highly Skilled Immigrants (0-1) (2)")
regress oppose_hs oppose_ls rc_YL45_53 rc_YL45_61 factscore usedpost female /*
  */age black white latino educ_hh ideo5 pid7 if low_cultural_threat == 1 & /*
  */YL45_49_69_treat == 1 & useme == 1 [aweight = weight], robust
outreg2 using Tables/TableJ03_PersonalSociotropicLowCulturalThreat, /*
  */lab alpha(0.001, 0.01, 0.05) dec(3) bracket aster(se) excel append /*
  */ctitle("Opposition to Admitting More Highly Skilled Immigrants (0-1) (3)")
outsum oppose_hs oppose_ls rc_YL45_53 rc_YL45_61 factscore usedpost female /*
  */age black white latino educ_hh ideo5 pid7 if low_cultural_threat == 1 & /*
  */YL45_49_69_treat == 1 & useme == 1 [aweight = weight] using /*
  */Tables/TableE03_SummaryStatsWeightedAppendix, bracket append /*
  */ctitle("Table J3, Highly Skilled Immigrants")
outsum oppose_hs oppose_ls rc_YL45_53 rc_YL45_61 factscore usedpost female /*
  */age black white latino educ_hh ideo5 pid7 if low_cultural_threat == 1 & /*
  */YL45_49_69_treat == 1 & useme == 1 using /*
  */Tables/TableE04_SummaryStatsUnweightedAppendix, bracket append /*
  */ctitle("Table J3, Highly Skilled Immigrants")

regress oppose_ls rc_YL45_53 usedpost female age black white latino educ_hh /*
  */ideo5 pid7 if low_cultural_threat == 1 & YL45_49_69_treat == 2 & /*
  */useme == 1 [aweight = weight], robust
outreg2 using Tables/TableJ03_PersonalSociotropicLowCulturalThreat, /*
  */lab alpha(0.001, 0.01, 0.05) dec(3) bracket aster(se) excel append /*
  */ctitle("Opposition to Admitting More Low-skilled Immigrants (0-1) (1)")
regress oppose_ls rc_YL45_53 rc_YL45_61 factscore usedpost female age black /*
  */white latino educ_hh ideo5 pid7 if low_cultural_threat == 1 & /*
  */YL45_49_69_treat == 2 & useme == 1 [aweight = weight], robust
outreg2 using Tables/TableJ03_PersonalSociotropicLowCulturalThreat, /*
  */lab alpha(0.001, 0.01, 0.05) dec(3) bracket aster(se) excel append /*
  */ctitle("Opposition to Admitting More Low-skilled Immigrants (0-1) (2)")
regress oppose_ls oppose_hs rc_YL45_53 rc_YL45_61 factscore usedpost female /*
  */age black white latino educ_hh ideo5 pid7 if low_cultural_threat == 1 & /*
  */YL45_49_69_treat == 2 & useme == 1 [aweight = weight], robust
outreg2 using Tables/TableJ03_PersonalSociotropicLowCulturalThreat, /*
  */lab alpha(0.001, 0.01, 0.05) dec(3) bracket aster(se) excel append /*
  */ctitle("Opposition to Admitting More Low-skilled Immigrants (0-1) (3)")
outsum oppose_ls oppose_hs rc_YL45_53 rc_YL45_61 factscore usedpost female /*
  */age black white latino educ_hh ideo5 pid7 if low_cultural_threat == 1 & /*
  */YL45_49_69_treat == 2 & useme == 1 [aweight = weight] using /*
  */Tables/TableE03_SummaryStatsWeightedAppendix, bracket append /*
  */ctitle("Table J3, Low-skilled Immigrants")
outsum oppose_ls oppose_hs rc_YL45_53 rc_YL45_61 factscore usedpost female /*
  */age black white latino educ_hh ideo5 pid7 if low_cultural_threat == 1 & /*
  */YL45_49_69_treat == 2 & useme == 1 using /*
  */Tables/TableE04_SummaryStatsUnweightedAppendix, bracket append /*
  */ctitle("Table J3, Low-skilled Immigrants")

gen outcome = oppose_ls if YL45_49_69_treat == 2
replace outcome = oppose_hs if YL45_49_69_treat == 1
label var outcome "Opposition to admitting immigrant of type (0-1)"

regress outcome immigrant_is_lowskilled usedpost female age black white /*
  */latino educ_hh ideo5 pid7 if low_cultural_threat == 1 & useme == 1 /*
  */[aweight = weight], robust
outreg2 using Tables/TableJ03_PersonalSociotropicLowCulturalThreat, /*
  */lab alpha(0.001, 0.01, 0.05) dec(3) bracket aster(se) excel append /*
  */ctitle("Pooled, Opposition to Admitting Immigrants of Type (0-1) (1)")
regress outcome rc_YL45_53 rc_YL45_61 factscore immigrant_is_lowskilled /*
  */usedpost female age black white latino educ_hh ideo5 pid7 if /*
  */low_cultural_threat == 1 & useme == 1 [aweight = weight], robust
outreg2 using Tables/TableJ03_PersonalSociotropicLowCulturalThreat, /*
  */lab alpha(0.001, 0.01, 0.05) dec(3) bracket aster(se) excel append /*
  */ctitle("Pooled, Opposition to Admitting Immigrants of Type (0-1) (2)")
outsum outcome rc_YL45_53 rc_YL45_61 factscore immigrant_is_lowskilled /*
  */usedpost female age black white latino educ_hh ideo5 pid7 if /*
  */low_cultural_threat == 1 & useme == 1 [aweight = weight] using /*
  */Tables/TableE03_SummaryStatsWeightedAppendix, bracket append /*
  */ctitle("Table J3, Pooled")
outsum outcome rc_YL45_53 rc_YL45_61 factscore immigrant_is_lowskilled /*
  */usedpost female age black white latino educ_hh ideo5 pid7 if /*
  */low_cultural_threat == 1 & useme == 1 using /*
  */Tables/TableE04_SummaryStatsUnweightedAppendix, bracket append /*
  */ctitle("Table J3, Pooled")

log close
